# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Section74Response(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_reference_number': 'str',
        'section_74_reference_number': 'str',
        'date_created': 'datetime',
        'overrun_warning_reasons': 'list[OverrunWarningReasonResponse]',
        'overrun_warning_reasons_string': 'list[str]',
        'ha_status': 'Section74HAStatusResponse',
        'ha_status_string': 'str',
        'location_description': 'str',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'inspection_date': 'datetime',
        'overrun_warning_details': 'str',
        'officer_name': 'str',
        'officer_contact_details': 'str',
        'section_74_evidence': 'bool',
        'files': 'list[FileSummaryResponse]',
        'latest_ha_response_date': 'datetime',
        'latest_promoter_response_date': 'datetime',
        'latest_ha_additional_details': 'str',
        'latest_promoter_additional_details': 'str',
        'ha_reason_for_dispute': 'str',
        'promoter_reason_for_dispute': 'str',
        'site_visited_date': 'datetime',
        'site_cleared_date': 'datetime',
        'ha_response_number_of_days_overrun': 'float',
        'draft_invoice_reference': 'str',
        'invoice_reference': 'str',
        'draft_invoice_amount': 'float',
        'final_agreed_amount': 'float',
        'promoter_status': 'AllOfSection74ResponsePromoterStatus',
        'promoter_status_string': 'str'
    }

    attribute_map = {
        'permit_reference_number': 'permit_reference_number',
        'section_74_reference_number': 'section_74_reference_number',
        'date_created': 'date_created',
        'overrun_warning_reasons': 'overrun_warning_reasons',
        'overrun_warning_reasons_string': 'overrun_warning_reasons_string',
        'ha_status': 'ha_status',
        'ha_status_string': 'ha_status_string',
        'location_description': 'location_description',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'inspection_date': 'inspection_date',
        'overrun_warning_details': 'overrun_warning_details',
        'officer_name': 'officer_name',
        'officer_contact_details': 'officer_contact_details',
        'section_74_evidence': 'section_74_evidence',
        'files': 'files',
        'latest_ha_response_date': 'latest_ha_response_date',
        'latest_promoter_response_date': 'latest_promoter_response_date',
        'latest_ha_additional_details': 'latest_ha_additional_details',
        'latest_promoter_additional_details': 'latest_promoter_additional_details',
        'ha_reason_for_dispute': 'ha_reason_for_dispute',
        'promoter_reason_for_dispute': 'promoter_reason_for_dispute',
        'site_visited_date': 'site_visited_date',
        'site_cleared_date': 'site_cleared_date',
        'ha_response_number_of_days_overrun': 'ha_response_number_of_days_overrun',
        'draft_invoice_reference': 'draft_invoice_reference',
        'invoice_reference': 'invoice_reference',
        'draft_invoice_amount': 'draft_invoice_amount',
        'final_agreed_amount': 'final_agreed_amount',
        'promoter_status': 'promoter_status',
        'promoter_status_string': 'promoter_status_string'
    }

    def __init__(self, permit_reference_number=None, section_74_reference_number=None, date_created=None, overrun_warning_reasons=None, overrun_warning_reasons_string=None, ha_status=None, ha_status_string=None, location_description=None, location_types=None, location_types_string=None, inspection_date=None, overrun_warning_details=None, officer_name=None, officer_contact_details=None, section_74_evidence=None, files=None, latest_ha_response_date=None, latest_promoter_response_date=None, latest_ha_additional_details=None, latest_promoter_additional_details=None, ha_reason_for_dispute=None, promoter_reason_for_dispute=None, site_visited_date=None, site_cleared_date=None, ha_response_number_of_days_overrun=None, draft_invoice_reference=None, invoice_reference=None, draft_invoice_amount=None, final_agreed_amount=None, promoter_status=None, promoter_status_string=None):  # noqa: E501
        """Section74Response - a model defined in Swagger"""  # noqa: E501
        self._permit_reference_number = None
        self._section_74_reference_number = None
        self._date_created = None
        self._overrun_warning_reasons = None
        self._overrun_warning_reasons_string = None
        self._ha_status = None
        self._ha_status_string = None
        self._location_description = None
        self._location_types = None
        self._location_types_string = None
        self._inspection_date = None
        self._overrun_warning_details = None
        self._officer_name = None
        self._officer_contact_details = None
        self._section_74_evidence = None
        self._files = None
        self._latest_ha_response_date = None
        self._latest_promoter_response_date = None
        self._latest_ha_additional_details = None
        self._latest_promoter_additional_details = None
        self._ha_reason_for_dispute = None
        self._promoter_reason_for_dispute = None
        self._site_visited_date = None
        self._site_cleared_date = None
        self._ha_response_number_of_days_overrun = None
        self._draft_invoice_reference = None
        self._invoice_reference = None
        self._draft_invoice_amount = None
        self._final_agreed_amount = None
        self._promoter_status = None
        self._promoter_status_string = None
        self.discriminator = None
        self.permit_reference_number = permit_reference_number
        self.section_74_reference_number = section_74_reference_number
        self.date_created = date_created
        self.overrun_warning_reasons = overrun_warning_reasons
        self.overrun_warning_reasons_string = overrun_warning_reasons_string
        self.ha_status = ha_status
        self.ha_status_string = ha_status_string
        self.location_description = location_description
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.inspection_date = inspection_date
        self.overrun_warning_details = overrun_warning_details
        self.officer_name = officer_name
        self.officer_contact_details = officer_contact_details
        self.section_74_evidence = section_74_evidence
        if files is not None:
            self.files = files
        if latest_ha_response_date is not None:
            self.latest_ha_response_date = latest_ha_response_date
        if latest_promoter_response_date is not None:
            self.latest_promoter_response_date = latest_promoter_response_date
        if latest_ha_additional_details is not None:
            self.latest_ha_additional_details = latest_ha_additional_details
        if latest_promoter_additional_details is not None:
            self.latest_promoter_additional_details = latest_promoter_additional_details
        if ha_reason_for_dispute is not None:
            self.ha_reason_for_dispute = ha_reason_for_dispute
        if promoter_reason_for_dispute is not None:
            self.promoter_reason_for_dispute = promoter_reason_for_dispute
        if site_visited_date is not None:
            self.site_visited_date = site_visited_date
        if site_cleared_date is not None:
            self.site_cleared_date = site_cleared_date
        if ha_response_number_of_days_overrun is not None:
            self.ha_response_number_of_days_overrun = ha_response_number_of_days_overrun
        if draft_invoice_reference is not None:
            self.draft_invoice_reference = draft_invoice_reference
        if invoice_reference is not None:
            self.invoice_reference = invoice_reference
        if draft_invoice_amount is not None:
            self.draft_invoice_amount = draft_invoice_amount
        if final_agreed_amount is not None:
            self.final_agreed_amount = final_agreed_amount
        if promoter_status is not None:
            self.promoter_status = promoter_status
        if promoter_status_string is not None:
            self.promoter_status_string = promoter_status_string

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this Section74Response.  # noqa: E501


        :return: The permit_reference_number of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this Section74Response.


        :param permit_reference_number: The permit_reference_number of this Section74Response.  # noqa: E501
        :type: str
        """
        if permit_reference_number is None:
            raise ValueError("Invalid value for `permit_reference_number`, must not be `None`")  # noqa: E501

        self._permit_reference_number = permit_reference_number

    @property
    def section_74_reference_number(self):
        """Gets the section_74_reference_number of this Section74Response.  # noqa: E501


        :return: The section_74_reference_number of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._section_74_reference_number

    @section_74_reference_number.setter
    def section_74_reference_number(self, section_74_reference_number):
        """Sets the section_74_reference_number of this Section74Response.


        :param section_74_reference_number: The section_74_reference_number of this Section74Response.  # noqa: E501
        :type: str
        """
        if section_74_reference_number is None:
            raise ValueError("Invalid value for `section_74_reference_number`, must not be `None`")  # noqa: E501

        self._section_74_reference_number = section_74_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this Section74Response.  # noqa: E501


        :return: The date_created of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this Section74Response.


        :param date_created: The date_created of this Section74Response.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def overrun_warning_reasons(self):
        """Gets the overrun_warning_reasons of this Section74Response.  # noqa: E501


        :return: The overrun_warning_reasons of this Section74Response.  # noqa: E501
        :rtype: list[OverrunWarningReasonResponse]
        """
        return self._overrun_warning_reasons

    @overrun_warning_reasons.setter
    def overrun_warning_reasons(self, overrun_warning_reasons):
        """Sets the overrun_warning_reasons of this Section74Response.


        :param overrun_warning_reasons: The overrun_warning_reasons of this Section74Response.  # noqa: E501
        :type: list[OverrunWarningReasonResponse]
        """
        if overrun_warning_reasons is None:
            raise ValueError("Invalid value for `overrun_warning_reasons`, must not be `None`")  # noqa: E501

        self._overrun_warning_reasons = overrun_warning_reasons

    @property
    def overrun_warning_reasons_string(self):
        """Gets the overrun_warning_reasons_string of this Section74Response.  # noqa: E501


        :return: The overrun_warning_reasons_string of this Section74Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._overrun_warning_reasons_string

    @overrun_warning_reasons_string.setter
    def overrun_warning_reasons_string(self, overrun_warning_reasons_string):
        """Sets the overrun_warning_reasons_string of this Section74Response.


        :param overrun_warning_reasons_string: The overrun_warning_reasons_string of this Section74Response.  # noqa: E501
        :type: list[str]
        """
        if overrun_warning_reasons_string is None:
            raise ValueError("Invalid value for `overrun_warning_reasons_string`, must not be `None`")  # noqa: E501

        self._overrun_warning_reasons_string = overrun_warning_reasons_string

    @property
    def ha_status(self):
        """Gets the ha_status of this Section74Response.  # noqa: E501


        :return: The ha_status of this Section74Response.  # noqa: E501
        :rtype: Section74HAStatusResponse
        """
        return self._ha_status

    @ha_status.setter
    def ha_status(self, ha_status):
        """Sets the ha_status of this Section74Response.


        :param ha_status: The ha_status of this Section74Response.  # noqa: E501
        :type: Section74HAStatusResponse
        """
        if ha_status is None:
            raise ValueError("Invalid value for `ha_status`, must not be `None`")  # noqa: E501

        self._ha_status = ha_status

    @property
    def ha_status_string(self):
        """Gets the ha_status_string of this Section74Response.  # noqa: E501


        :return: The ha_status_string of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._ha_status_string

    @ha_status_string.setter
    def ha_status_string(self, ha_status_string):
        """Sets the ha_status_string of this Section74Response.


        :param ha_status_string: The ha_status_string of this Section74Response.  # noqa: E501
        :type: str
        """
        if ha_status_string is None:
            raise ValueError("Invalid value for `ha_status_string`, must not be `None`")  # noqa: E501

        self._ha_status_string = ha_status_string

    @property
    def location_description(self):
        """Gets the location_description of this Section74Response.  # noqa: E501


        :return: The location_description of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._location_description

    @location_description.setter
    def location_description(self, location_description):
        """Sets the location_description of this Section74Response.


        :param location_description: The location_description of this Section74Response.  # noqa: E501
        :type: str
        """
        if location_description is None:
            raise ValueError("Invalid value for `location_description`, must not be `None`")  # noqa: E501

        self._location_description = location_description

    @property
    def location_types(self):
        """Gets the location_types of this Section74Response.  # noqa: E501


        :return: The location_types of this Section74Response.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this Section74Response.


        :param location_types: The location_types of this Section74Response.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this Section74Response.  # noqa: E501


        :return: The location_types_string of this Section74Response.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this Section74Response.


        :param location_types_string: The location_types_string of this Section74Response.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def inspection_date(self):
        """Gets the inspection_date of this Section74Response.  # noqa: E501


        :return: The inspection_date of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._inspection_date

    @inspection_date.setter
    def inspection_date(self, inspection_date):
        """Sets the inspection_date of this Section74Response.


        :param inspection_date: The inspection_date of this Section74Response.  # noqa: E501
        :type: datetime
        """
        if inspection_date is None:
            raise ValueError("Invalid value for `inspection_date`, must not be `None`")  # noqa: E501

        self._inspection_date = inspection_date

    @property
    def overrun_warning_details(self):
        """Gets the overrun_warning_details of this Section74Response.  # noqa: E501


        :return: The overrun_warning_details of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._overrun_warning_details

    @overrun_warning_details.setter
    def overrun_warning_details(self, overrun_warning_details):
        """Sets the overrun_warning_details of this Section74Response.


        :param overrun_warning_details: The overrun_warning_details of this Section74Response.  # noqa: E501
        :type: str
        """
        if overrun_warning_details is None:
            raise ValueError("Invalid value for `overrun_warning_details`, must not be `None`")  # noqa: E501

        self._overrun_warning_details = overrun_warning_details

    @property
    def officer_name(self):
        """Gets the officer_name of this Section74Response.  # noqa: E501


        :return: The officer_name of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._officer_name

    @officer_name.setter
    def officer_name(self, officer_name):
        """Sets the officer_name of this Section74Response.


        :param officer_name: The officer_name of this Section74Response.  # noqa: E501
        :type: str
        """
        if officer_name is None:
            raise ValueError("Invalid value for `officer_name`, must not be `None`")  # noqa: E501

        self._officer_name = officer_name

    @property
    def officer_contact_details(self):
        """Gets the officer_contact_details of this Section74Response.  # noqa: E501


        :return: The officer_contact_details of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._officer_contact_details

    @officer_contact_details.setter
    def officer_contact_details(self, officer_contact_details):
        """Sets the officer_contact_details of this Section74Response.


        :param officer_contact_details: The officer_contact_details of this Section74Response.  # noqa: E501
        :type: str
        """
        if officer_contact_details is None:
            raise ValueError("Invalid value for `officer_contact_details`, must not be `None`")  # noqa: E501

        self._officer_contact_details = officer_contact_details

    @property
    def section_74_evidence(self):
        """Gets the section_74_evidence of this Section74Response.  # noqa: E501


        :return: The section_74_evidence of this Section74Response.  # noqa: E501
        :rtype: bool
        """
        return self._section_74_evidence

    @section_74_evidence.setter
    def section_74_evidence(self, section_74_evidence):
        """Sets the section_74_evidence of this Section74Response.


        :param section_74_evidence: The section_74_evidence of this Section74Response.  # noqa: E501
        :type: bool
        """
        if section_74_evidence is None:
            raise ValueError("Invalid value for `section_74_evidence`, must not be `None`")  # noqa: E501

        self._section_74_evidence = section_74_evidence

    @property
    def files(self):
        """Gets the files of this Section74Response.  # noqa: E501


        :return: The files of this Section74Response.  # noqa: E501
        :rtype: list[FileSummaryResponse]
        """
        return self._files

    @files.setter
    def files(self, files):
        """Sets the files of this Section74Response.


        :param files: The files of this Section74Response.  # noqa: E501
        :type: list[FileSummaryResponse]
        """

        self._files = files

    @property
    def latest_ha_response_date(self):
        """Gets the latest_ha_response_date of this Section74Response.  # noqa: E501


        :return: The latest_ha_response_date of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._latest_ha_response_date

    @latest_ha_response_date.setter
    def latest_ha_response_date(self, latest_ha_response_date):
        """Sets the latest_ha_response_date of this Section74Response.


        :param latest_ha_response_date: The latest_ha_response_date of this Section74Response.  # noqa: E501
        :type: datetime
        """

        self._latest_ha_response_date = latest_ha_response_date

    @property
    def latest_promoter_response_date(self):
        """Gets the latest_promoter_response_date of this Section74Response.  # noqa: E501


        :return: The latest_promoter_response_date of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._latest_promoter_response_date

    @latest_promoter_response_date.setter
    def latest_promoter_response_date(self, latest_promoter_response_date):
        """Sets the latest_promoter_response_date of this Section74Response.


        :param latest_promoter_response_date: The latest_promoter_response_date of this Section74Response.  # noqa: E501
        :type: datetime
        """

        self._latest_promoter_response_date = latest_promoter_response_date

    @property
    def latest_ha_additional_details(self):
        """Gets the latest_ha_additional_details of this Section74Response.  # noqa: E501


        :return: The latest_ha_additional_details of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._latest_ha_additional_details

    @latest_ha_additional_details.setter
    def latest_ha_additional_details(self, latest_ha_additional_details):
        """Sets the latest_ha_additional_details of this Section74Response.


        :param latest_ha_additional_details: The latest_ha_additional_details of this Section74Response.  # noqa: E501
        :type: str
        """

        self._latest_ha_additional_details = latest_ha_additional_details

    @property
    def latest_promoter_additional_details(self):
        """Gets the latest_promoter_additional_details of this Section74Response.  # noqa: E501


        :return: The latest_promoter_additional_details of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._latest_promoter_additional_details

    @latest_promoter_additional_details.setter
    def latest_promoter_additional_details(self, latest_promoter_additional_details):
        """Sets the latest_promoter_additional_details of this Section74Response.


        :param latest_promoter_additional_details: The latest_promoter_additional_details of this Section74Response.  # noqa: E501
        :type: str
        """

        self._latest_promoter_additional_details = latest_promoter_additional_details

    @property
    def ha_reason_for_dispute(self):
        """Gets the ha_reason_for_dispute of this Section74Response.  # noqa: E501


        :return: The ha_reason_for_dispute of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._ha_reason_for_dispute

    @ha_reason_for_dispute.setter
    def ha_reason_for_dispute(self, ha_reason_for_dispute):
        """Sets the ha_reason_for_dispute of this Section74Response.


        :param ha_reason_for_dispute: The ha_reason_for_dispute of this Section74Response.  # noqa: E501
        :type: str
        """

        self._ha_reason_for_dispute = ha_reason_for_dispute

    @property
    def promoter_reason_for_dispute(self):
        """Gets the promoter_reason_for_dispute of this Section74Response.  # noqa: E501


        :return: The promoter_reason_for_dispute of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_reason_for_dispute

    @promoter_reason_for_dispute.setter
    def promoter_reason_for_dispute(self, promoter_reason_for_dispute):
        """Sets the promoter_reason_for_dispute of this Section74Response.


        :param promoter_reason_for_dispute: The promoter_reason_for_dispute of this Section74Response.  # noqa: E501
        :type: str
        """

        self._promoter_reason_for_dispute = promoter_reason_for_dispute

    @property
    def site_visited_date(self):
        """Gets the site_visited_date of this Section74Response.  # noqa: E501


        :return: The site_visited_date of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._site_visited_date

    @site_visited_date.setter
    def site_visited_date(self, site_visited_date):
        """Sets the site_visited_date of this Section74Response.


        :param site_visited_date: The site_visited_date of this Section74Response.  # noqa: E501
        :type: datetime
        """

        self._site_visited_date = site_visited_date

    @property
    def site_cleared_date(self):
        """Gets the site_cleared_date of this Section74Response.  # noqa: E501


        :return: The site_cleared_date of this Section74Response.  # noqa: E501
        :rtype: datetime
        """
        return self._site_cleared_date

    @site_cleared_date.setter
    def site_cleared_date(self, site_cleared_date):
        """Sets the site_cleared_date of this Section74Response.


        :param site_cleared_date: The site_cleared_date of this Section74Response.  # noqa: E501
        :type: datetime
        """

        self._site_cleared_date = site_cleared_date

    @property
    def ha_response_number_of_days_overrun(self):
        """Gets the ha_response_number_of_days_overrun of this Section74Response.  # noqa: E501


        :return: The ha_response_number_of_days_overrun of this Section74Response.  # noqa: E501
        :rtype: float
        """
        return self._ha_response_number_of_days_overrun

    @ha_response_number_of_days_overrun.setter
    def ha_response_number_of_days_overrun(self, ha_response_number_of_days_overrun):
        """Sets the ha_response_number_of_days_overrun of this Section74Response.


        :param ha_response_number_of_days_overrun: The ha_response_number_of_days_overrun of this Section74Response.  # noqa: E501
        :type: float
        """

        self._ha_response_number_of_days_overrun = ha_response_number_of_days_overrun

    @property
    def draft_invoice_reference(self):
        """Gets the draft_invoice_reference of this Section74Response.  # noqa: E501


        :return: The draft_invoice_reference of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._draft_invoice_reference

    @draft_invoice_reference.setter
    def draft_invoice_reference(self, draft_invoice_reference):
        """Sets the draft_invoice_reference of this Section74Response.


        :param draft_invoice_reference: The draft_invoice_reference of this Section74Response.  # noqa: E501
        :type: str
        """

        self._draft_invoice_reference = draft_invoice_reference

    @property
    def invoice_reference(self):
        """Gets the invoice_reference of this Section74Response.  # noqa: E501


        :return: The invoice_reference of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._invoice_reference

    @invoice_reference.setter
    def invoice_reference(self, invoice_reference):
        """Sets the invoice_reference of this Section74Response.


        :param invoice_reference: The invoice_reference of this Section74Response.  # noqa: E501
        :type: str
        """

        self._invoice_reference = invoice_reference

    @property
    def draft_invoice_amount(self):
        """Gets the draft_invoice_amount of this Section74Response.  # noqa: E501


        :return: The draft_invoice_amount of this Section74Response.  # noqa: E501
        :rtype: float
        """
        return self._draft_invoice_amount

    @draft_invoice_amount.setter
    def draft_invoice_amount(self, draft_invoice_amount):
        """Sets the draft_invoice_amount of this Section74Response.


        :param draft_invoice_amount: The draft_invoice_amount of this Section74Response.  # noqa: E501
        :type: float
        """

        self._draft_invoice_amount = draft_invoice_amount

    @property
    def final_agreed_amount(self):
        """Gets the final_agreed_amount of this Section74Response.  # noqa: E501


        :return: The final_agreed_amount of this Section74Response.  # noqa: E501
        :rtype: float
        """
        return self._final_agreed_amount

    @final_agreed_amount.setter
    def final_agreed_amount(self, final_agreed_amount):
        """Sets the final_agreed_amount of this Section74Response.


        :param final_agreed_amount: The final_agreed_amount of this Section74Response.  # noqa: E501
        :type: float
        """

        self._final_agreed_amount = final_agreed_amount

    @property
    def promoter_status(self):
        """Gets the promoter_status of this Section74Response.  # noqa: E501


        :return: The promoter_status of this Section74Response.  # noqa: E501
        :rtype: AllOfSection74ResponsePromoterStatus
        """
        return self._promoter_status

    @promoter_status.setter
    def promoter_status(self, promoter_status):
        """Sets the promoter_status of this Section74Response.


        :param promoter_status: The promoter_status of this Section74Response.  # noqa: E501
        :type: AllOfSection74ResponsePromoterStatus
        """

        self._promoter_status = promoter_status

    @property
    def promoter_status_string(self):
        """Gets the promoter_status_string of this Section74Response.  # noqa: E501


        :return: The promoter_status_string of this Section74Response.  # noqa: E501
        :rtype: str
        """
        return self._promoter_status_string

    @promoter_status_string.setter
    def promoter_status_string(self, promoter_status_string):
        """Sets the promoter_status_string of this Section74Response.


        :param promoter_status_string: The promoter_status_string of this Section74Response.  # noqa: E501
        :type: str
        """

        self._promoter_status_string = promoter_status_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Section74Response, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Section74Response):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PermitSummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'permit_reference_number': 'str',
        'proposed_start_date': 'datetime',
        'proposed_end_date': 'datetime',
        'actual_start_date': 'datetime',
        'actual_stop_date': 'datetime',
        'permit_status': 'PermitStatusResponse',
        'permit_status_string': 'str',
        'work_category': 'WorkCategoryResponseEnum',
        'work_category_string': 'str'
    }

    attribute_map = {
        'permit_reference_number': 'permit_reference_number',
        'proposed_start_date': 'proposed_start_date',
        'proposed_end_date': 'proposed_end_date',
        'actual_start_date': 'actual_start_date',
        'actual_stop_date': 'actual_stop_date',
        'permit_status': 'permit_status',
        'permit_status_string': 'permit_status_string',
        'work_category': 'work_category',
        'work_category_string': 'work_category_string'
    }

    def __init__(self, permit_reference_number=None, proposed_start_date=None, proposed_end_date=None, actual_start_date=None, actual_stop_date=None, permit_status=None, permit_status_string=None, work_category=None, work_category_string=None):  # noqa: E501
        """PermitSummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._permit_reference_number = None
        self._proposed_start_date = None
        self._proposed_end_date = None
        self._actual_start_date = None
        self._actual_stop_date = None
        self._permit_status = None
        self._permit_status_string = None
        self._work_category = None
        self._work_category_string = None
        self.discriminator = None
        self.permit_reference_number = permit_reference_number
        self.proposed_start_date = proposed_start_date
        self.proposed_end_date = proposed_end_date
        if actual_start_date is not None:
            self.actual_start_date = actual_start_date
        if actual_stop_date is not None:
            self.actual_stop_date = actual_stop_date
        self.permit_status = permit_status
        self.permit_status_string = permit_status_string
        self.work_category = work_category
        self.work_category_string = work_category_string

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this PermitSummaryResponse.  # noqa: E501


        :return: The permit_reference_number of this PermitSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this PermitSummaryResponse.


        :param permit_reference_number: The permit_reference_number of this PermitSummaryResponse.  # noqa: E501
        :type: str
        """
        if permit_reference_number is None:
            raise ValueError("Invalid value for `permit_reference_number`, must not be `None`")  # noqa: E501

        self._permit_reference_number = permit_reference_number

    @property
    def proposed_start_date(self):
        """Gets the proposed_start_date of this PermitSummaryResponse.  # noqa: E501


        :return: The proposed_start_date of this PermitSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_start_date

    @proposed_start_date.setter
    def proposed_start_date(self, proposed_start_date):
        """Sets the proposed_start_date of this PermitSummaryResponse.


        :param proposed_start_date: The proposed_start_date of this PermitSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_start_date is None:
            raise ValueError("Invalid value for `proposed_start_date`, must not be `None`")  # noqa: E501

        self._proposed_start_date = proposed_start_date

    @property
    def proposed_end_date(self):
        """Gets the proposed_end_date of this PermitSummaryResponse.  # noqa: E501


        :return: The proposed_end_date of this PermitSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._proposed_end_date

    @proposed_end_date.setter
    def proposed_end_date(self, proposed_end_date):
        """Sets the proposed_end_date of this PermitSummaryResponse.


        :param proposed_end_date: The proposed_end_date of this PermitSummaryResponse.  # noqa: E501
        :type: datetime
        """
        if proposed_end_date is None:
            raise ValueError("Invalid value for `proposed_end_date`, must not be `None`")  # noqa: E501

        self._proposed_end_date = proposed_end_date

    @property
    def actual_start_date(self):
        """Gets the actual_start_date of this PermitSummaryResponse.  # noqa: E501


        :return: The actual_start_date of this PermitSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._actual_start_date

    @actual_start_date.setter
    def actual_start_date(self, actual_start_date):
        """Sets the actual_start_date of this PermitSummaryResponse.


        :param actual_start_date: The actual_start_date of this PermitSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._actual_start_date = actual_start_date

    @property
    def actual_stop_date(self):
        """Gets the actual_stop_date of this PermitSummaryResponse.  # noqa: E501


        :return: The actual_stop_date of this PermitSummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._actual_stop_date

    @actual_stop_date.setter
    def actual_stop_date(self, actual_stop_date):
        """Sets the actual_stop_date of this PermitSummaryResponse.


        :param actual_stop_date: The actual_stop_date of this PermitSummaryResponse.  # noqa: E501
        :type: datetime
        """

        self._actual_stop_date = actual_stop_date

    @property
    def permit_status(self):
        """Gets the permit_status of this PermitSummaryResponse.  # noqa: E501


        :return: The permit_status of this PermitSummaryResponse.  # noqa: E501
        :rtype: PermitStatusResponse
        """
        return self._permit_status

    @permit_status.setter
    def permit_status(self, permit_status):
        """Sets the permit_status of this PermitSummaryResponse.


        :param permit_status: The permit_status of this PermitSummaryResponse.  # noqa: E501
        :type: PermitStatusResponse
        """
        if permit_status is None:
            raise ValueError("Invalid value for `permit_status`, must not be `None`")  # noqa: E501

        self._permit_status = permit_status

    @property
    def permit_status_string(self):
        """Gets the permit_status_string of this PermitSummaryResponse.  # noqa: E501


        :return: The permit_status_string of this PermitSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._permit_status_string

    @permit_status_string.setter
    def permit_status_string(self, permit_status_string):
        """Sets the permit_status_string of this PermitSummaryResponse.


        :param permit_status_string: The permit_status_string of this PermitSummaryResponse.  # noqa: E501
        :type: str
        """
        if permit_status_string is None:
            raise ValueError("Invalid value for `permit_status_string`, must not be `None`")  # noqa: E501

        self._permit_status_string = permit_status_string

    @property
    def work_category(self):
        """Gets the work_category of this PermitSummaryResponse.  # noqa: E501


        :return: The work_category of this PermitSummaryResponse.  # noqa: E501
        :rtype: WorkCategoryResponseEnum
        """
        return self._work_category

    @work_category.setter
    def work_category(self, work_category):
        """Sets the work_category of this PermitSummaryResponse.


        :param work_category: The work_category of this PermitSummaryResponse.  # noqa: E501
        :type: WorkCategoryResponseEnum
        """
        if work_category is None:
            raise ValueError("Invalid value for `work_category`, must not be `None`")  # noqa: E501

        self._work_category = work_category

    @property
    def work_category_string(self):
        """Gets the work_category_string of this PermitSummaryResponse.  # noqa: E501


        :return: The work_category_string of this PermitSummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_category_string

    @work_category_string.setter
    def work_category_string(self, work_category_string):
        """Sets the work_category_string of this PermitSummaryResponse.


        :param work_category_string: The work_category_string of this PermitSummaryResponse.  # noqa: E501
        :type: str
        """
        if work_category_string is None:
            raise ValueError("Invalid value for `work_category_string`, must not be `None`")  # noqa: E501

        self._work_category_string = work_category_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PermitSummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PermitSummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'activity_reference_number': 'str',
        'usrn': 'float',
        'street_name': 'str',
        'town': 'str',
        'area_name': 'str',
        'road_category': 'float',
        'activity_coordinates': 'object',
        'activity_name': 'str',
        'activity_activity_type': 'ActivityActivityTypeResponse',
        'activity_activity_type_string': 'str',
        'activity_type_details': 'str',
        'contact_name': 'str',
        'contact_details': 'str',
        'start_date': 'datetime',
        'start_time': 'datetime',
        'end_date': 'datetime',
        'end_time': 'datetime',
        'location_types': 'list[LocationTypeResponse]',
        'location_types_string': 'list[str]',
        'activity_location_description': 'str',
        'traffic_management_type': 'TrafficManagementTypeResponse',
        'traffic_management_type_string': 'str',
        'collaborative_working': 'bool',
        'additional_info': 'str',
        'cancelled': 'bool',
        'cancelled_reason': 'str',
        'highway_authority_swa_code': 'str'
    }

    attribute_map = {
        'activity_reference_number': 'activity_reference_number',
        'usrn': 'usrn',
        'street_name': 'street_name',
        'town': 'town',
        'area_name': 'area_name',
        'road_category': 'road_category',
        'activity_coordinates': 'activity_coordinates',
        'activity_name': 'activity_name',
        'activity_activity_type': 'activity_activity_type',
        'activity_activity_type_string': 'activity_activity_type_string',
        'activity_type_details': 'activity_type_details',
        'contact_name': 'contact_name',
        'contact_details': 'contact_details',
        'start_date': 'start_date',
        'start_time': 'start_time',
        'end_date': 'end_date',
        'end_time': 'end_time',
        'location_types': 'location_types',
        'location_types_string': 'location_types_string',
        'activity_location_description': 'activity_location_description',
        'traffic_management_type': 'traffic_management_type',
        'traffic_management_type_string': 'traffic_management_type_string',
        'collaborative_working': 'collaborative_working',
        'additional_info': 'additional_info',
        'cancelled': 'cancelled',
        'cancelled_reason': 'cancelled_reason',
        'highway_authority_swa_code': 'highway_authority_swa_code'
    }

    def __init__(self, activity_reference_number=None, usrn=None, street_name=None, town=None, area_name=None, road_category=None, activity_coordinates=None, activity_name=None, activity_activity_type=None, activity_activity_type_string=None, activity_type_details=None, contact_name=None, contact_details=None, start_date=None, start_time=None, end_date=None, end_time=None, location_types=None, location_types_string=None, activity_location_description=None, traffic_management_type=None, traffic_management_type_string=None, collaborative_working=None, additional_info=None, cancelled=None, cancelled_reason=None, highway_authority_swa_code=None):  # noqa: E501
        """ActivityResponse - a model defined in Swagger"""  # noqa: E501
        self._activity_reference_number = None
        self._usrn = None
        self._street_name = None
        self._town = None
        self._area_name = None
        self._road_category = None
        self._activity_coordinates = None
        self._activity_name = None
        self._activity_activity_type = None
        self._activity_activity_type_string = None
        self._activity_type_details = None
        self._contact_name = None
        self._contact_details = None
        self._start_date = None
        self._start_time = None
        self._end_date = None
        self._end_time = None
        self._location_types = None
        self._location_types_string = None
        self._activity_location_description = None
        self._traffic_management_type = None
        self._traffic_management_type_string = None
        self._collaborative_working = None
        self._additional_info = None
        self._cancelled = None
        self._cancelled_reason = None
        self._highway_authority_swa_code = None
        self.discriminator = None
        self.activity_reference_number = activity_reference_number
        self.usrn = usrn
        if street_name is not None:
            self.street_name = street_name
        if town is not None:
            self.town = town
        if area_name is not None:
            self.area_name = area_name
        if road_category is not None:
            self.road_category = road_category
        self.activity_coordinates = activity_coordinates
        self.activity_name = activity_name
        self.activity_activity_type = activity_activity_type
        self.activity_activity_type_string = activity_activity_type_string
        if activity_type_details is not None:
            self.activity_type_details = activity_type_details
        if contact_name is not None:
            self.contact_name = contact_name
        if contact_details is not None:
            self.contact_details = contact_details
        self.start_date = start_date
        if start_time is not None:
            self.start_time = start_time
        self.end_date = end_date
        if end_time is not None:
            self.end_time = end_time
        self.location_types = location_types
        self.location_types_string = location_types_string
        self.activity_location_description = activity_location_description
        self.traffic_management_type = traffic_management_type
        self.traffic_management_type_string = traffic_management_type_string
        self.collaborative_working = collaborative_working
        if additional_info is not None:
            self.additional_info = additional_info
        self.cancelled = cancelled
        if cancelled_reason is not None:
            self.cancelled_reason = cancelled_reason
        self.highway_authority_swa_code = highway_authority_swa_code

    @property
    def activity_reference_number(self):
        """Gets the activity_reference_number of this ActivityResponse.  # noqa: E501


        :return: The activity_reference_number of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._activity_reference_number

    @activity_reference_number.setter
    def activity_reference_number(self, activity_reference_number):
        """Sets the activity_reference_number of this ActivityResponse.


        :param activity_reference_number: The activity_reference_number of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if activity_reference_number is None:
            raise ValueError("Invalid value for `activity_reference_number`, must not be `None`")  # noqa: E501

        self._activity_reference_number = activity_reference_number

    @property
    def usrn(self):
        """Gets the usrn of this ActivityResponse.  # noqa: E501


        :return: The usrn of this ActivityResponse.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this ActivityResponse.


        :param usrn: The usrn of this ActivityResponse.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def street_name(self):
        """Gets the street_name of this ActivityResponse.  # noqa: E501


        :return: The street_name of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """Sets the street_name of this ActivityResponse.


        :param street_name: The street_name of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._street_name = street_name

    @property
    def town(self):
        """Gets the town of this ActivityResponse.  # noqa: E501


        :return: The town of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this ActivityResponse.


        :param town: The town of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._town = town

    @property
    def area_name(self):
        """Gets the area_name of this ActivityResponse.  # noqa: E501


        :return: The area_name of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._area_name

    @area_name.setter
    def area_name(self, area_name):
        """Sets the area_name of this ActivityResponse.


        :param area_name: The area_name of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._area_name = area_name

    @property
    def road_category(self):
        """Gets the road_category of this ActivityResponse.  # noqa: E501


        :return: The road_category of this ActivityResponse.  # noqa: E501
        :rtype: float
        """
        return self._road_category

    @road_category.setter
    def road_category(self, road_category):
        """Sets the road_category of this ActivityResponse.


        :param road_category: The road_category of this ActivityResponse.  # noqa: E501
        :type: float
        """

        self._road_category = road_category

    @property
    def activity_coordinates(self):
        """Gets the activity_coordinates of this ActivityResponse.  # noqa: E501


        :return: The activity_coordinates of this ActivityResponse.  # noqa: E501
        :rtype: object
        """
        return self._activity_coordinates

    @activity_coordinates.setter
    def activity_coordinates(self, activity_coordinates):
        """Sets the activity_coordinates of this ActivityResponse.


        :param activity_coordinates: The activity_coordinates of this ActivityResponse.  # noqa: E501
        :type: object
        """
        if activity_coordinates is None:
            raise ValueError("Invalid value for `activity_coordinates`, must not be `None`")  # noqa: E501

        self._activity_coordinates = activity_coordinates

    @property
    def activity_name(self):
        """Gets the activity_name of this ActivityResponse.  # noqa: E501


        :return: The activity_name of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._activity_name

    @activity_name.setter
    def activity_name(self, activity_name):
        """Sets the activity_name of this ActivityResponse.


        :param activity_name: The activity_name of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if activity_name is None:
            raise ValueError("Invalid value for `activity_name`, must not be `None`")  # noqa: E501

        self._activity_name = activity_name

    @property
    def activity_activity_type(self):
        """Gets the activity_activity_type of this ActivityResponse.  # noqa: E501


        :return: The activity_activity_type of this ActivityResponse.  # noqa: E501
        :rtype: ActivityActivityTypeResponse
        """
        return self._activity_activity_type

    @activity_activity_type.setter
    def activity_activity_type(self, activity_activity_type):
        """Sets the activity_activity_type of this ActivityResponse.


        :param activity_activity_type: The activity_activity_type of this ActivityResponse.  # noqa: E501
        :type: ActivityActivityTypeResponse
        """
        if activity_activity_type is None:
            raise ValueError("Invalid value for `activity_activity_type`, must not be `None`")  # noqa: E501

        self._activity_activity_type = activity_activity_type

    @property
    def activity_activity_type_string(self):
        """Gets the activity_activity_type_string of this ActivityResponse.  # noqa: E501


        :return: The activity_activity_type_string of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._activity_activity_type_string

    @activity_activity_type_string.setter
    def activity_activity_type_string(self, activity_activity_type_string):
        """Sets the activity_activity_type_string of this ActivityResponse.


        :param activity_activity_type_string: The activity_activity_type_string of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if activity_activity_type_string is None:
            raise ValueError("Invalid value for `activity_activity_type_string`, must not be `None`")  # noqa: E501

        self._activity_activity_type_string = activity_activity_type_string

    @property
    def activity_type_details(self):
        """Gets the activity_type_details of this ActivityResponse.  # noqa: E501


        :return: The activity_type_details of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._activity_type_details

    @activity_type_details.setter
    def activity_type_details(self, activity_type_details):
        """Sets the activity_type_details of this ActivityResponse.


        :param activity_type_details: The activity_type_details of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._activity_type_details = activity_type_details

    @property
    def contact_name(self):
        """Gets the contact_name of this ActivityResponse.  # noqa: E501


        :return: The contact_name of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_name

    @contact_name.setter
    def contact_name(self, contact_name):
        """Sets the contact_name of this ActivityResponse.


        :param contact_name: The contact_name of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._contact_name = contact_name

    @property
    def contact_details(self):
        """Gets the contact_details of this ActivityResponse.  # noqa: E501


        :return: The contact_details of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._contact_details

    @contact_details.setter
    def contact_details(self, contact_details):
        """Sets the contact_details of this ActivityResponse.


        :param contact_details: The contact_details of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._contact_details = contact_details

    @property
    def start_date(self):
        """Gets the start_date of this ActivityResponse.  # noqa: E501


        :return: The start_date of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this ActivityResponse.


        :param start_date: The start_date of this ActivityResponse.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def start_time(self):
        """Gets the start_time of this ActivityResponse.  # noqa: E501


        :return: The start_time of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this ActivityResponse.


        :param start_time: The start_time of this ActivityResponse.  # noqa: E501
        :type: datetime
        """

        self._start_time = start_time

    @property
    def end_date(self):
        """Gets the end_date of this ActivityResponse.  # noqa: E501


        :return: The end_date of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this ActivityResponse.


        :param end_date: The end_date of this ActivityResponse.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def end_time(self):
        """Gets the end_time of this ActivityResponse.  # noqa: E501


        :return: The end_time of this ActivityResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """Sets the end_time of this ActivityResponse.


        :param end_time: The end_time of this ActivityResponse.  # noqa: E501
        :type: datetime
        """

        self._end_time = end_time

    @property
    def location_types(self):
        """Gets the location_types of this ActivityResponse.  # noqa: E501


        :return: The location_types of this ActivityResponse.  # noqa: E501
        :rtype: list[LocationTypeResponse]
        """
        return self._location_types

    @location_types.setter
    def location_types(self, location_types):
        """Sets the location_types of this ActivityResponse.


        :param location_types: The location_types of this ActivityResponse.  # noqa: E501
        :type: list[LocationTypeResponse]
        """
        if location_types is None:
            raise ValueError("Invalid value for `location_types`, must not be `None`")  # noqa: E501

        self._location_types = location_types

    @property
    def location_types_string(self):
        """Gets the location_types_string of this ActivityResponse.  # noqa: E501


        :return: The location_types_string of this ActivityResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._location_types_string

    @location_types_string.setter
    def location_types_string(self, location_types_string):
        """Sets the location_types_string of this ActivityResponse.


        :param location_types_string: The location_types_string of this ActivityResponse.  # noqa: E501
        :type: list[str]
        """
        if location_types_string is None:
            raise ValueError("Invalid value for `location_types_string`, must not be `None`")  # noqa: E501

        self._location_types_string = location_types_string

    @property
    def activity_location_description(self):
        """Gets the activity_location_description of this ActivityResponse.  # noqa: E501


        :return: The activity_location_description of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._activity_location_description

    @activity_location_description.setter
    def activity_location_description(self, activity_location_description):
        """Sets the activity_location_description of this ActivityResponse.


        :param activity_location_description: The activity_location_description of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if activity_location_description is None:
            raise ValueError("Invalid value for `activity_location_description`, must not be `None`")  # noqa: E501

        self._activity_location_description = activity_location_description

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this ActivityResponse.  # noqa: E501


        :return: The traffic_management_type of this ActivityResponse.  # noqa: E501
        :rtype: TrafficManagementTypeResponse
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this ActivityResponse.


        :param traffic_management_type: The traffic_management_type of this ActivityResponse.  # noqa: E501
        :type: TrafficManagementTypeResponse
        """
        if traffic_management_type is None:
            raise ValueError("Invalid value for `traffic_management_type`, must not be `None`")  # noqa: E501

        self._traffic_management_type = traffic_management_type

    @property
    def traffic_management_type_string(self):
        """Gets the traffic_management_type_string of this ActivityResponse.  # noqa: E501


        :return: The traffic_management_type_string of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._traffic_management_type_string

    @traffic_management_type_string.setter
    def traffic_management_type_string(self, traffic_management_type_string):
        """Sets the traffic_management_type_string of this ActivityResponse.


        :param traffic_management_type_string: The traffic_management_type_string of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if traffic_management_type_string is None:
            raise ValueError("Invalid value for `traffic_management_type_string`, must not be `None`")  # noqa: E501

        self._traffic_management_type_string = traffic_management_type_string

    @property
    def collaborative_working(self):
        """Gets the collaborative_working of this ActivityResponse.  # noqa: E501


        :return: The collaborative_working of this ActivityResponse.  # noqa: E501
        :rtype: bool
        """
        return self._collaborative_working

    @collaborative_working.setter
    def collaborative_working(self, collaborative_working):
        """Sets the collaborative_working of this ActivityResponse.


        :param collaborative_working: The collaborative_working of this ActivityResponse.  # noqa: E501
        :type: bool
        """
        if collaborative_working is None:
            raise ValueError("Invalid value for `collaborative_working`, must not be `None`")  # noqa: E501

        self._collaborative_working = collaborative_working

    @property
    def additional_info(self):
        """Gets the additional_info of this ActivityResponse.  # noqa: E501


        :return: The additional_info of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._additional_info

    @additional_info.setter
    def additional_info(self, additional_info):
        """Sets the additional_info of this ActivityResponse.


        :param additional_info: The additional_info of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._additional_info = additional_info

    @property
    def cancelled(self):
        """Gets the cancelled of this ActivityResponse.  # noqa: E501


        :return: The cancelled of this ActivityResponse.  # noqa: E501
        :rtype: bool
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this ActivityResponse.


        :param cancelled: The cancelled of this ActivityResponse.  # noqa: E501
        :type: bool
        """
        if cancelled is None:
            raise ValueError("Invalid value for `cancelled`, must not be `None`")  # noqa: E501

        self._cancelled = cancelled

    @property
    def cancelled_reason(self):
        """Gets the cancelled_reason of this ActivityResponse.  # noqa: E501


        :return: The cancelled_reason of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._cancelled_reason

    @cancelled_reason.setter
    def cancelled_reason(self, cancelled_reason):
        """Sets the cancelled_reason of this ActivityResponse.


        :param cancelled_reason: The cancelled_reason of this ActivityResponse.  # noqa: E501
        :type: str
        """

        self._cancelled_reason = cancelled_reason

    @property
    def highway_authority_swa_code(self):
        """Gets the highway_authority_swa_code of this ActivityResponse.  # noqa: E501


        :return: The highway_authority_swa_code of this ActivityResponse.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority_swa_code

    @highway_authority_swa_code.setter
    def highway_authority_swa_code(self, highway_authority_swa_code):
        """Sets the highway_authority_swa_code of this ActivityResponse.


        :param highway_authority_swa_code: The highway_authority_swa_code of this ActivityResponse.  # noqa: E501
        :type: str
        """
        if highway_authority_swa_code is None:
            raise ValueError("Invalid value for `highway_authority_swa_code`, must not be `None`")  # noqa: E501

        self._highway_authority_swa_code = highway_authority_swa_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class NonComplianceResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'non_compliance_reference_number': 'str',
        'work_reference_number': 'str',
        'date_created': 'datetime',
        'non_compliance_status': 'NonComplianceStatusResponse',
        'non_compliance_status_string': 'str',
        'jsm_requested_by': 'str',
        'jsm_suggested_time': 'datetime',
        'jsm_status': 'AllOfNonComplianceResponseJsmStatus',
        'jsm_status_string': 'str',
        'promoter_response_status': 'AllOfNonComplianceResponsePromoterResponseStatus',
        'promoter_response_status_string': 'str',
        'promoter_response_update_date': 'datetime',
        'promoter_response_additional_details': 'str',
        'promoter_response_jsm_date': 'datetime',
        'ha_response_status': 'NonComplianceResponseStatusResponse',
        'ha_response_status_string': 'str',
        'ha_response_update_date': 'datetime',
        'ha_response_additional_details': 'str',
        'ha_response_jsm_date': 'datetime',
        'latest_inspection': 'InspectionResponse',
        'linked_inspections': 'list[InspectionSummaryResponse]',
        'linked_permits': 'list[PermitSummaryResponse]'
    }

    attribute_map = {
        'non_compliance_reference_number': 'non_compliance_reference_number',
        'work_reference_number': 'work_reference_number',
        'date_created': 'date_created',
        'non_compliance_status': 'non_compliance_status',
        'non_compliance_status_string': 'non_compliance_status_string',
        'jsm_requested_by': 'jsm_requested_by',
        'jsm_suggested_time': 'jsm_suggested_time',
        'jsm_status': 'jsm_status',
        'jsm_status_string': 'jsm_status_string',
        'promoter_response_status': 'promoter_response_status',
        'promoter_response_status_string': 'promoter_response_status_string',
        'promoter_response_update_date': 'promoter_response_update_date',
        'promoter_response_additional_details': 'promoter_response_additional_details',
        'promoter_response_jsm_date': 'promoter_response_jsm_date',
        'ha_response_status': 'ha_response_status',
        'ha_response_status_string': 'ha_response_status_string',
        'ha_response_update_date': 'ha_response_update_date',
        'ha_response_additional_details': 'ha_response_additional_details',
        'ha_response_jsm_date': 'ha_response_jsm_date',
        'latest_inspection': 'latest_inspection',
        'linked_inspections': 'linked_inspections',
        'linked_permits': 'linked_permits'
    }

    def __init__(self, non_compliance_reference_number=None, work_reference_number=None, date_created=None, non_compliance_status=None, non_compliance_status_string=None, jsm_requested_by=None, jsm_suggested_time=None, jsm_status=None, jsm_status_string=None, promoter_response_status=None, promoter_response_status_string=None, promoter_response_update_date=None, promoter_response_additional_details=None, promoter_response_jsm_date=None, ha_response_status=None, ha_response_status_string=None, ha_response_update_date=None, ha_response_additional_details=None, ha_response_jsm_date=None, latest_inspection=None, linked_inspections=None, linked_permits=None):  # noqa: E501
        """NonComplianceResponse - a model defined in Swagger"""  # noqa: E501
        self._non_compliance_reference_number = None
        self._work_reference_number = None
        self._date_created = None
        self._non_compliance_status = None
        self._non_compliance_status_string = None
        self._jsm_requested_by = None
        self._jsm_suggested_time = None
        self._jsm_status = None
        self._jsm_status_string = None
        self._promoter_response_status = None
        self._promoter_response_status_string = None
        self._promoter_response_update_date = None
        self._promoter_response_additional_details = None
        self._promoter_response_jsm_date = None
        self._ha_response_status = None
        self._ha_response_status_string = None
        self._ha_response_update_date = None
        self._ha_response_additional_details = None
        self._ha_response_jsm_date = None
        self._latest_inspection = None
        self._linked_inspections = None
        self._linked_permits = None
        self.discriminator = None
        self.non_compliance_reference_number = non_compliance_reference_number
        self.work_reference_number = work_reference_number
        self.date_created = date_created
        self.non_compliance_status = non_compliance_status
        self.non_compliance_status_string = non_compliance_status_string
        if jsm_requested_by is not None:
            self.jsm_requested_by = jsm_requested_by
        if jsm_suggested_time is not None:
            self.jsm_suggested_time = jsm_suggested_time
        if jsm_status is not None:
            self.jsm_status = jsm_status
        if jsm_status_string is not None:
            self.jsm_status_string = jsm_status_string
        if promoter_response_status is not None:
            self.promoter_response_status = promoter_response_status
        if promoter_response_status_string is not None:
            self.promoter_response_status_string = promoter_response_status_string
        if promoter_response_update_date is not None:
            self.promoter_response_update_date = promoter_response_update_date
        if promoter_response_additional_details is not None:
            self.promoter_response_additional_details = promoter_response_additional_details
        if promoter_response_jsm_date is not None:
            self.promoter_response_jsm_date = promoter_response_jsm_date
        self.ha_response_status = ha_response_status
        self.ha_response_status_string = ha_response_status_string
        if ha_response_update_date is not None:
            self.ha_response_update_date = ha_response_update_date
        if ha_response_additional_details is not None:
            self.ha_response_additional_details = ha_response_additional_details
        if ha_response_jsm_date is not None:
            self.ha_response_jsm_date = ha_response_jsm_date
        self.latest_inspection = latest_inspection
        self.linked_inspections = linked_inspections
        if linked_permits is not None:
            self.linked_permits = linked_permits

    @property
    def non_compliance_reference_number(self):
        """Gets the non_compliance_reference_number of this NonComplianceResponse.  # noqa: E501


        :return: The non_compliance_reference_number of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._non_compliance_reference_number

    @non_compliance_reference_number.setter
    def non_compliance_reference_number(self, non_compliance_reference_number):
        """Sets the non_compliance_reference_number of this NonComplianceResponse.


        :param non_compliance_reference_number: The non_compliance_reference_number of this NonComplianceResponse.  # noqa: E501
        :type: str
        """
        if non_compliance_reference_number is None:
            raise ValueError("Invalid value for `non_compliance_reference_number`, must not be `None`")  # noqa: E501

        self._non_compliance_reference_number = non_compliance_reference_number

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this NonComplianceResponse.  # noqa: E501


        :return: The work_reference_number of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this NonComplianceResponse.


        :param work_reference_number: The work_reference_number of this NonComplianceResponse.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def date_created(self):
        """Gets the date_created of this NonComplianceResponse.  # noqa: E501


        :return: The date_created of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """Sets the date_created of this NonComplianceResponse.


        :param date_created: The date_created of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """
        if date_created is None:
            raise ValueError("Invalid value for `date_created`, must not be `None`")  # noqa: E501

        self._date_created = date_created

    @property
    def non_compliance_status(self):
        """Gets the non_compliance_status of this NonComplianceResponse.  # noqa: E501


        :return: The non_compliance_status of this NonComplianceResponse.  # noqa: E501
        :rtype: NonComplianceStatusResponse
        """
        return self._non_compliance_status

    @non_compliance_status.setter
    def non_compliance_status(self, non_compliance_status):
        """Sets the non_compliance_status of this NonComplianceResponse.


        :param non_compliance_status: The non_compliance_status of this NonComplianceResponse.  # noqa: E501
        :type: NonComplianceStatusResponse
        """
        if non_compliance_status is None:
            raise ValueError("Invalid value for `non_compliance_status`, must not be `None`")  # noqa: E501

        self._non_compliance_status = non_compliance_status

    @property
    def non_compliance_status_string(self):
        """Gets the non_compliance_status_string of this NonComplianceResponse.  # noqa: E501


        :return: The non_compliance_status_string of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._non_compliance_status_string

    @non_compliance_status_string.setter
    def non_compliance_status_string(self, non_compliance_status_string):
        """Sets the non_compliance_status_string of this NonComplianceResponse.


        :param non_compliance_status_string: The non_compliance_status_string of this NonComplianceResponse.  # noqa: E501
        :type: str
        """
        if non_compliance_status_string is None:
            raise ValueError("Invalid value for `non_compliance_status_string`, must not be `None`")  # noqa: E501

        self._non_compliance_status_string = non_compliance_status_string

    @property
    def jsm_requested_by(self):
        """Gets the jsm_requested_by of this NonComplianceResponse.  # noqa: E501


        :return: The jsm_requested_by of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._jsm_requested_by

    @jsm_requested_by.setter
    def jsm_requested_by(self, jsm_requested_by):
        """Sets the jsm_requested_by of this NonComplianceResponse.


        :param jsm_requested_by: The jsm_requested_by of this NonComplianceResponse.  # noqa: E501
        :type: str
        """

        self._jsm_requested_by = jsm_requested_by

    @property
    def jsm_suggested_time(self):
        """Gets the jsm_suggested_time of this NonComplianceResponse.  # noqa: E501


        :return: The jsm_suggested_time of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._jsm_suggested_time

    @jsm_suggested_time.setter
    def jsm_suggested_time(self, jsm_suggested_time):
        """Sets the jsm_suggested_time of this NonComplianceResponse.


        :param jsm_suggested_time: The jsm_suggested_time of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """

        self._jsm_suggested_time = jsm_suggested_time

    @property
    def jsm_status(self):
        """Gets the jsm_status of this NonComplianceResponse.  # noqa: E501


        :return: The jsm_status of this NonComplianceResponse.  # noqa: E501
        :rtype: AllOfNonComplianceResponseJsmStatus
        """
        return self._jsm_status

    @jsm_status.setter
    def jsm_status(self, jsm_status):
        """Sets the jsm_status of this NonComplianceResponse.


        :param jsm_status: The jsm_status of this NonComplianceResponse.  # noqa: E501
        :type: AllOfNonComplianceResponseJsmStatus
        """

        self._jsm_status = jsm_status

    @property
    def jsm_status_string(self):
        """Gets the jsm_status_string of this NonComplianceResponse.  # noqa: E501


        :return: The jsm_status_string of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._jsm_status_string

    @jsm_status_string.setter
    def jsm_status_string(self, jsm_status_string):
        """Sets the jsm_status_string of this NonComplianceResponse.


        :param jsm_status_string: The jsm_status_string of this NonComplianceResponse.  # noqa: E501
        :type: str
        """

        self._jsm_status_string = jsm_status_string

    @property
    def promoter_response_status(self):
        """Gets the promoter_response_status of this NonComplianceResponse.  # noqa: E501


        :return: The promoter_response_status of this NonComplianceResponse.  # noqa: E501
        :rtype: AllOfNonComplianceResponsePromoterResponseStatus
        """
        return self._promoter_response_status

    @promoter_response_status.setter
    def promoter_response_status(self, promoter_response_status):
        """Sets the promoter_response_status of this NonComplianceResponse.


        :param promoter_response_status: The promoter_response_status of this NonComplianceResponse.  # noqa: E501
        :type: AllOfNonComplianceResponsePromoterResponseStatus
        """

        self._promoter_response_status = promoter_response_status

    @property
    def promoter_response_status_string(self):
        """Gets the promoter_response_status_string of this NonComplianceResponse.  # noqa: E501


        :return: The promoter_response_status_string of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_status_string

    @promoter_response_status_string.setter
    def promoter_response_status_string(self, promoter_response_status_string):
        """Sets the promoter_response_status_string of this NonComplianceResponse.


        :param promoter_response_status_string: The promoter_response_status_string of this NonComplianceResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_status_string = promoter_response_status_string

    @property
    def promoter_response_update_date(self):
        """Gets the promoter_response_update_date of this NonComplianceResponse.  # noqa: E501


        :return: The promoter_response_update_date of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._promoter_response_update_date

    @promoter_response_update_date.setter
    def promoter_response_update_date(self, promoter_response_update_date):
        """Sets the promoter_response_update_date of this NonComplianceResponse.


        :param promoter_response_update_date: The promoter_response_update_date of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """

        self._promoter_response_update_date = promoter_response_update_date

    @property
    def promoter_response_additional_details(self):
        """Gets the promoter_response_additional_details of this NonComplianceResponse.  # noqa: E501


        :return: The promoter_response_additional_details of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._promoter_response_additional_details

    @promoter_response_additional_details.setter
    def promoter_response_additional_details(self, promoter_response_additional_details):
        """Sets the promoter_response_additional_details of this NonComplianceResponse.


        :param promoter_response_additional_details: The promoter_response_additional_details of this NonComplianceResponse.  # noqa: E501
        :type: str
        """

        self._promoter_response_additional_details = promoter_response_additional_details

    @property
    def promoter_response_jsm_date(self):
        """Gets the promoter_response_jsm_date of this NonComplianceResponse.  # noqa: E501


        :return: The promoter_response_jsm_date of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._promoter_response_jsm_date

    @promoter_response_jsm_date.setter
    def promoter_response_jsm_date(self, promoter_response_jsm_date):
        """Sets the promoter_response_jsm_date of this NonComplianceResponse.


        :param promoter_response_jsm_date: The promoter_response_jsm_date of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """

        self._promoter_response_jsm_date = promoter_response_jsm_date

    @property
    def ha_response_status(self):
        """Gets the ha_response_status of this NonComplianceResponse.  # noqa: E501


        :return: The ha_response_status of this NonComplianceResponse.  # noqa: E501
        :rtype: NonComplianceResponseStatusResponse
        """
        return self._ha_response_status

    @ha_response_status.setter
    def ha_response_status(self, ha_response_status):
        """Sets the ha_response_status of this NonComplianceResponse.


        :param ha_response_status: The ha_response_status of this NonComplianceResponse.  # noqa: E501
        :type: NonComplianceResponseStatusResponse
        """
        if ha_response_status is None:
            raise ValueError("Invalid value for `ha_response_status`, must not be `None`")  # noqa: E501

        self._ha_response_status = ha_response_status

    @property
    def ha_response_status_string(self):
        """Gets the ha_response_status_string of this NonComplianceResponse.  # noqa: E501


        :return: The ha_response_status_string of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_status_string

    @ha_response_status_string.setter
    def ha_response_status_string(self, ha_response_status_string):
        """Sets the ha_response_status_string of this NonComplianceResponse.


        :param ha_response_status_string: The ha_response_status_string of this NonComplianceResponse.  # noqa: E501
        :type: str
        """
        if ha_response_status_string is None:
            raise ValueError("Invalid value for `ha_response_status_string`, must not be `None`")  # noqa: E501

        self._ha_response_status_string = ha_response_status_string

    @property
    def ha_response_update_date(self):
        """Gets the ha_response_update_date of this NonComplianceResponse.  # noqa: E501


        :return: The ha_response_update_date of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._ha_response_update_date

    @ha_response_update_date.setter
    def ha_response_update_date(self, ha_response_update_date):
        """Sets the ha_response_update_date of this NonComplianceResponse.


        :param ha_response_update_date: The ha_response_update_date of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """

        self._ha_response_update_date = ha_response_update_date

    @property
    def ha_response_additional_details(self):
        """Gets the ha_response_additional_details of this NonComplianceResponse.  # noqa: E501


        :return: The ha_response_additional_details of this NonComplianceResponse.  # noqa: E501
        :rtype: str
        """
        return self._ha_response_additional_details

    @ha_response_additional_details.setter
    def ha_response_additional_details(self, ha_response_additional_details):
        """Sets the ha_response_additional_details of this NonComplianceResponse.


        :param ha_response_additional_details: The ha_response_additional_details of this NonComplianceResponse.  # noqa: E501
        :type: str
        """

        self._ha_response_additional_details = ha_response_additional_details

    @property
    def ha_response_jsm_date(self):
        """Gets the ha_response_jsm_date of this NonComplianceResponse.  # noqa: E501


        :return: The ha_response_jsm_date of this NonComplianceResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._ha_response_jsm_date

    @ha_response_jsm_date.setter
    def ha_response_jsm_date(self, ha_response_jsm_date):
        """Sets the ha_response_jsm_date of this NonComplianceResponse.


        :param ha_response_jsm_date: The ha_response_jsm_date of this NonComplianceResponse.  # noqa: E501
        :type: datetime
        """

        self._ha_response_jsm_date = ha_response_jsm_date

    @property
    def latest_inspection(self):
        """Gets the latest_inspection of this NonComplianceResponse.  # noqa: E501


        :return: The latest_inspection of this NonComplianceResponse.  # noqa: E501
        :rtype: InspectionResponse
        """
        return self._latest_inspection

    @latest_inspection.setter
    def latest_inspection(self, latest_inspection):
        """Sets the latest_inspection of this NonComplianceResponse.


        :param latest_inspection: The latest_inspection of this NonComplianceResponse.  # noqa: E501
        :type: InspectionResponse
        """
        if latest_inspection is None:
            raise ValueError("Invalid value for `latest_inspection`, must not be `None`")  # noqa: E501

        self._latest_inspection = latest_inspection

    @property
    def linked_inspections(self):
        """Gets the linked_inspections of this NonComplianceResponse.  # noqa: E501


        :return: The linked_inspections of this NonComplianceResponse.  # noqa: E501
        :rtype: list[InspectionSummaryResponse]
        """
        return self._linked_inspections

    @linked_inspections.setter
    def linked_inspections(self, linked_inspections):
        """Sets the linked_inspections of this NonComplianceResponse.


        :param linked_inspections: The linked_inspections of this NonComplianceResponse.  # noqa: E501
        :type: list[InspectionSummaryResponse]
        """
        if linked_inspections is None:
            raise ValueError("Invalid value for `linked_inspections`, must not be `None`")  # noqa: E501

        self._linked_inspections = linked_inspections

    @property
    def linked_permits(self):
        """Gets the linked_permits of this NonComplianceResponse.  # noqa: E501


        :return: The linked_permits of this NonComplianceResponse.  # noqa: E501
        :rtype: list[PermitSummaryResponse]
        """
        return self._linked_permits

    @linked_permits.setter
    def linked_permits(self, linked_permits):
        """Sets the linked_permits of this NonComplianceResponse.


        :param linked_permits: The linked_permits of this NonComplianceResponse.  # noqa: E501
        :type: list[PermitSummaryResponse]
        """

        self._linked_permits = linked_permits

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(NonComplianceResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NonComplianceResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MaterialClassificationProperties(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'material_classification_reference_number': 'str',
        'material_classification_classification': 'MaterialClassificationClassificationResponse',
        'material_classification_classification_string': 'str',
        'sample_date': 'datetime',
        'recorded_by_swa_code': 'str',
        'recorded_by_organisation_name': 'str',
        'usrn': 'float',
        'material_type': 'list[MaterialClassificationMaterialTypeResponse]',
        'material_type_string': 'list[str]',
        'material_classification_centre_point': 'GeoJSONCentrePoint'
    }

    attribute_map = {
        'material_classification_reference_number': 'material_classification_reference_number',
        'material_classification_classification': 'material_classification_classification',
        'material_classification_classification_string': 'material_classification_classification_string',
        'sample_date': 'sample_date',
        'recorded_by_swa_code': 'recorded_by_swa_code',
        'recorded_by_organisation_name': 'recorded_by_organisation_name',
        'usrn': 'usrn',
        'material_type': 'material_type',
        'material_type_string': 'material_type_string',
        'material_classification_centre_point': 'material_classification_centre_point'
    }

    def __init__(self, material_classification_reference_number=None, material_classification_classification=None, material_classification_classification_string=None, sample_date=None, recorded_by_swa_code=None, recorded_by_organisation_name=None, usrn=None, material_type=None, material_type_string=None, material_classification_centre_point=None):  # noqa: E501
        """MaterialClassificationProperties - a model defined in Swagger"""  # noqa: E501
        self._material_classification_reference_number = None
        self._material_classification_classification = None
        self._material_classification_classification_string = None
        self._sample_date = None
        self._recorded_by_swa_code = None
        self._recorded_by_organisation_name = None
        self._usrn = None
        self._material_type = None
        self._material_type_string = None
        self._material_classification_centre_point = None
        self.discriminator = None
        self.material_classification_reference_number = material_classification_reference_number
        self.material_classification_classification = material_classification_classification
        self.material_classification_classification_string = material_classification_classification_string
        self.sample_date = sample_date
        self.recorded_by_swa_code = recorded_by_swa_code
        self.recorded_by_organisation_name = recorded_by_organisation_name
        self.usrn = usrn
        if material_type is not None:
            self.material_type = material_type
        if material_type_string is not None:
            self.material_type_string = material_type_string
        self.material_classification_centre_point = material_classification_centre_point

    @property
    def material_classification_reference_number(self):
        """Gets the material_classification_reference_number of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_classification_reference_number of this MaterialClassificationProperties.  # noqa: E501
        :rtype: str
        """
        return self._material_classification_reference_number

    @material_classification_reference_number.setter
    def material_classification_reference_number(self, material_classification_reference_number):
        """Sets the material_classification_reference_number of this MaterialClassificationProperties.


        :param material_classification_reference_number: The material_classification_reference_number of this MaterialClassificationProperties.  # noqa: E501
        :type: str
        """
        if material_classification_reference_number is None:
            raise ValueError("Invalid value for `material_classification_reference_number`, must not be `None`")  # noqa: E501

        self._material_classification_reference_number = material_classification_reference_number

    @property
    def material_classification_classification(self):
        """Gets the material_classification_classification of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_classification_classification of this MaterialClassificationProperties.  # noqa: E501
        :rtype: MaterialClassificationClassificationResponse
        """
        return self._material_classification_classification

    @material_classification_classification.setter
    def material_classification_classification(self, material_classification_classification):
        """Sets the material_classification_classification of this MaterialClassificationProperties.


        :param material_classification_classification: The material_classification_classification of this MaterialClassificationProperties.  # noqa: E501
        :type: MaterialClassificationClassificationResponse
        """
        if material_classification_classification is None:
            raise ValueError("Invalid value for `material_classification_classification`, must not be `None`")  # noqa: E501

        self._material_classification_classification = material_classification_classification

    @property
    def material_classification_classification_string(self):
        """Gets the material_classification_classification_string of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_classification_classification_string of this MaterialClassificationProperties.  # noqa: E501
        :rtype: str
        """
        return self._material_classification_classification_string

    @material_classification_classification_string.setter
    def material_classification_classification_string(self, material_classification_classification_string):
        """Sets the material_classification_classification_string of this MaterialClassificationProperties.


        :param material_classification_classification_string: The material_classification_classification_string of this MaterialClassificationProperties.  # noqa: E501
        :type: str
        """
        if material_classification_classification_string is None:
            raise ValueError("Invalid value for `material_classification_classification_string`, must not be `None`")  # noqa: E501

        self._material_classification_classification_string = material_classification_classification_string

    @property
    def sample_date(self):
        """Gets the sample_date of this MaterialClassificationProperties.  # noqa: E501


        :return: The sample_date of this MaterialClassificationProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._sample_date

    @sample_date.setter
    def sample_date(self, sample_date):
        """Sets the sample_date of this MaterialClassificationProperties.


        :param sample_date: The sample_date of this MaterialClassificationProperties.  # noqa: E501
        :type: datetime
        """
        if sample_date is None:
            raise ValueError("Invalid value for `sample_date`, must not be `None`")  # noqa: E501

        self._sample_date = sample_date

    @property
    def recorded_by_swa_code(self):
        """Gets the recorded_by_swa_code of this MaterialClassificationProperties.  # noqa: E501


        :return: The recorded_by_swa_code of this MaterialClassificationProperties.  # noqa: E501
        :rtype: str
        """
        return self._recorded_by_swa_code

    @recorded_by_swa_code.setter
    def recorded_by_swa_code(self, recorded_by_swa_code):
        """Sets the recorded_by_swa_code of this MaterialClassificationProperties.


        :param recorded_by_swa_code: The recorded_by_swa_code of this MaterialClassificationProperties.  # noqa: E501
        :type: str
        """
        if recorded_by_swa_code is None:
            raise ValueError("Invalid value for `recorded_by_swa_code`, must not be `None`")  # noqa: E501

        self._recorded_by_swa_code = recorded_by_swa_code

    @property
    def recorded_by_organisation_name(self):
        """Gets the recorded_by_organisation_name of this MaterialClassificationProperties.  # noqa: E501


        :return: The recorded_by_organisation_name of this MaterialClassificationProperties.  # noqa: E501
        :rtype: str
        """
        return self._recorded_by_organisation_name

    @recorded_by_organisation_name.setter
    def recorded_by_organisation_name(self, recorded_by_organisation_name):
        """Sets the recorded_by_organisation_name of this MaterialClassificationProperties.


        :param recorded_by_organisation_name: The recorded_by_organisation_name of this MaterialClassificationProperties.  # noqa: E501
        :type: str
        """
        if recorded_by_organisation_name is None:
            raise ValueError("Invalid value for `recorded_by_organisation_name`, must not be `None`")  # noqa: E501

        self._recorded_by_organisation_name = recorded_by_organisation_name

    @property
    def usrn(self):
        """Gets the usrn of this MaterialClassificationProperties.  # noqa: E501


        :return: The usrn of this MaterialClassificationProperties.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this MaterialClassificationProperties.


        :param usrn: The usrn of this MaterialClassificationProperties.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def material_type(self):
        """Gets the material_type of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_type of this MaterialClassificationProperties.  # noqa: E501
        :rtype: list[MaterialClassificationMaterialTypeResponse]
        """
        return self._material_type

    @material_type.setter
    def material_type(self, material_type):
        """Sets the material_type of this MaterialClassificationProperties.


        :param material_type: The material_type of this MaterialClassificationProperties.  # noqa: E501
        :type: list[MaterialClassificationMaterialTypeResponse]
        """

        self._material_type = material_type

    @property
    def material_type_string(self):
        """Gets the material_type_string of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_type_string of this MaterialClassificationProperties.  # noqa: E501
        :rtype: list[str]
        """
        return self._material_type_string

    @material_type_string.setter
    def material_type_string(self, material_type_string):
        """Sets the material_type_string of this MaterialClassificationProperties.


        :param material_type_string: The material_type_string of this MaterialClassificationProperties.  # noqa: E501
        :type: list[str]
        """

        self._material_type_string = material_type_string

    @property
    def material_classification_centre_point(self):
        """Gets the material_classification_centre_point of this MaterialClassificationProperties.  # noqa: E501


        :return: The material_classification_centre_point of this MaterialClassificationProperties.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._material_classification_centre_point

    @material_classification_centre_point.setter
    def material_classification_centre_point(self, material_classification_centre_point):
        """Sets the material_classification_centre_point of this MaterialClassificationProperties.


        :param material_classification_centre_point: The material_classification_centre_point of this MaterialClassificationProperties.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if material_classification_centre_point is None:
            raise ValueError("Invalid value for `material_classification_centre_point`, must not be `None`")  # noqa: E501

        self._material_classification_centre_point = material_classification_centre_point

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MaterialClassificationProperties, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MaterialClassificationProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager GeoJSON API

    See API specification Resource Guide > GeoJSON API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkProperties(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'work_reference_number': 'str',
        'permit_reference_number': 'str',
        'promoter_organisation': 'str',
        'promoter_swa_code': 'str',
        'work_category': 'WorkCategoryResponse',
        'work_category_string': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'traffic_management_type': 'TrafficManagementTypeResponse',
        'traffic_management_type_string': 'str',
        'current_traffic_management_type': 'TrafficManagementTypeResponse',
        'current_traffic_management_type_string': 'str',
        'current_traffic_management_update_date': 'datetime',
        'street': 'str',
        'usrn': 'float',
        'town': 'str',
        'area': 'str',
        'highway_authority': 'str',
        'work_centre_point': 'GeoJSONCentrePoint',
        'permit_status': 'PermitStatusResponse',
        'permit_status_string': 'str',
        'industry_sector': 'AllOfWorkPropertiesIndustrySector',
        'industry_sector_string': 'str'
    }

    attribute_map = {
        'work_reference_number': 'work_reference_number',
        'permit_reference_number': 'permit_reference_number',
        'promoter_organisation': 'promoter_organisation',
        'promoter_swa_code': 'promoter_swa_code',
        'work_category': 'work_category',
        'work_category_string': 'work_category_string',
        'start_date': 'start_date',
        'end_date': 'end_date',
        'traffic_management_type': 'traffic_management_type',
        'traffic_management_type_string': 'traffic_management_type_string',
        'current_traffic_management_type': 'current_traffic_management_type',
        'current_traffic_management_type_string': 'current_traffic_management_type_string',
        'current_traffic_management_update_date': 'current_traffic_management_update_date',
        'street': 'street',
        'usrn': 'usrn',
        'town': 'town',
        'area': 'area',
        'highway_authority': 'highway_authority',
        'work_centre_point': 'work_centre_point',
        'permit_status': 'permit_status',
        'permit_status_string': 'permit_status_string',
        'industry_sector': 'industry_sector',
        'industry_sector_string': 'industry_sector_string'
    }

    def __init__(self, work_reference_number=None, permit_reference_number=None, promoter_organisation=None, promoter_swa_code=None, work_category=None, work_category_string=None, start_date=None, end_date=None, traffic_management_type=None, traffic_management_type_string=None, current_traffic_management_type=None, current_traffic_management_type_string=None, current_traffic_management_update_date=None, street=None, usrn=None, town=None, area=None, highway_authority=None, work_centre_point=None, permit_status=None, permit_status_string=None, industry_sector=None, industry_sector_string=None):  # noqa: E501
        """WorkProperties - a model defined in Swagger"""  # noqa: E501
        self._work_reference_number = None
        self._permit_reference_number = None
        self._promoter_organisation = None
        self._promoter_swa_code = None
        self._work_category = None
        self._work_category_string = None
        self._start_date = None
        self._end_date = None
        self._traffic_management_type = None
        self._traffic_management_type_string = None
        self._current_traffic_management_type = None
        self._current_traffic_management_type_string = None
        self._current_traffic_management_update_date = None
        self._street = None
        self._usrn = None
        self._town = None
        self._area = None
        self._highway_authority = None
        self._work_centre_point = None
        self._permit_status = None
        self._permit_status_string = None
        self._industry_sector = None
        self._industry_sector_string = None
        self.discriminator = None
        self.work_reference_number = work_reference_number
        self.permit_reference_number = permit_reference_number
        self.promoter_organisation = promoter_organisation
        self.promoter_swa_code = promoter_swa_code
        self.work_category = work_category
        self.work_category_string = work_category_string
        self.start_date = start_date
        self.end_date = end_date
        self.traffic_management_type = traffic_management_type
        self.traffic_management_type_string = traffic_management_type_string
        if current_traffic_management_type is not None:
            self.current_traffic_management_type = current_traffic_management_type
        if current_traffic_management_type_string is not None:
            self.current_traffic_management_type_string = current_traffic_management_type_string
        if current_traffic_management_update_date is not None:
            self.current_traffic_management_update_date = current_traffic_management_update_date
        self.street = street
        self.usrn = usrn
        self.town = town
        self.area = area
        self.highway_authority = highway_authority
        self.work_centre_point = work_centre_point
        self.permit_status = permit_status
        self.permit_status_string = permit_status_string
        if industry_sector is not None:
            self.industry_sector = industry_sector
        if industry_sector_string is not None:
            self.industry_sector_string = industry_sector_string

    @property
    def work_reference_number(self):
        """Gets the work_reference_number of this WorkProperties.  # noqa: E501


        :return: The work_reference_number of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._work_reference_number

    @work_reference_number.setter
    def work_reference_number(self, work_reference_number):
        """Sets the work_reference_number of this WorkProperties.


        :param work_reference_number: The work_reference_number of this WorkProperties.  # noqa: E501
        :type: str
        """
        if work_reference_number is None:
            raise ValueError("Invalid value for `work_reference_number`, must not be `None`")  # noqa: E501

        self._work_reference_number = work_reference_number

    @property
    def permit_reference_number(self):
        """Gets the permit_reference_number of this WorkProperties.  # noqa: E501


        :return: The permit_reference_number of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._permit_reference_number

    @permit_reference_number.setter
    def permit_reference_number(self, permit_reference_number):
        """Sets the permit_reference_number of this WorkProperties.


        :param permit_reference_number: The permit_reference_number of this WorkProperties.  # noqa: E501
        :type: str
        """
        if permit_reference_number is None:
            raise ValueError("Invalid value for `permit_reference_number`, must not be `None`")  # noqa: E501

        self._permit_reference_number = permit_reference_number

    @property
    def promoter_organisation(self):
        """Gets the promoter_organisation of this WorkProperties.  # noqa: E501


        :return: The promoter_organisation of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._promoter_organisation

    @promoter_organisation.setter
    def promoter_organisation(self, promoter_organisation):
        """Sets the promoter_organisation of this WorkProperties.


        :param promoter_organisation: The promoter_organisation of this WorkProperties.  # noqa: E501
        :type: str
        """
        if promoter_organisation is None:
            raise ValueError("Invalid value for `promoter_organisation`, must not be `None`")  # noqa: E501

        self._promoter_organisation = promoter_organisation

    @property
    def promoter_swa_code(self):
        """Gets the promoter_swa_code of this WorkProperties.  # noqa: E501


        :return: The promoter_swa_code of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._promoter_swa_code

    @promoter_swa_code.setter
    def promoter_swa_code(self, promoter_swa_code):
        """Sets the promoter_swa_code of this WorkProperties.


        :param promoter_swa_code: The promoter_swa_code of this WorkProperties.  # noqa: E501
        :type: str
        """
        if promoter_swa_code is None:
            raise ValueError("Invalid value for `promoter_swa_code`, must not be `None`")  # noqa: E501

        self._promoter_swa_code = promoter_swa_code

    @property
    def work_category(self):
        """Gets the work_category of this WorkProperties.  # noqa: E501


        :return: The work_category of this WorkProperties.  # noqa: E501
        :rtype: WorkCategoryResponse
        """
        return self._work_category

    @work_category.setter
    def work_category(self, work_category):
        """Sets the work_category of this WorkProperties.


        :param work_category: The work_category of this WorkProperties.  # noqa: E501
        :type: WorkCategoryResponse
        """
        if work_category is None:
            raise ValueError("Invalid value for `work_category`, must not be `None`")  # noqa: E501

        self._work_category = work_category

    @property
    def work_category_string(self):
        """Gets the work_category_string of this WorkProperties.  # noqa: E501


        :return: The work_category_string of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._work_category_string

    @work_category_string.setter
    def work_category_string(self, work_category_string):
        """Sets the work_category_string of this WorkProperties.


        :param work_category_string: The work_category_string of this WorkProperties.  # noqa: E501
        :type: str
        """
        if work_category_string is None:
            raise ValueError("Invalid value for `work_category_string`, must not be `None`")  # noqa: E501

        self._work_category_string = work_category_string

    @property
    def start_date(self):
        """Gets the start_date of this WorkProperties.  # noqa: E501


        :return: The start_date of this WorkProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this WorkProperties.


        :param start_date: The start_date of this WorkProperties.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this WorkProperties.  # noqa: E501


        :return: The end_date of this WorkProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this WorkProperties.


        :param end_date: The end_date of this WorkProperties.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def traffic_management_type(self):
        """Gets the traffic_management_type of this WorkProperties.  # noqa: E501


        :return: The traffic_management_type of this WorkProperties.  # noqa: E501
        :rtype: TrafficManagementTypeResponse
        """
        return self._traffic_management_type

    @traffic_management_type.setter
    def traffic_management_type(self, traffic_management_type):
        """Sets the traffic_management_type of this WorkProperties.


        :param traffic_management_type: The traffic_management_type of this WorkProperties.  # noqa: E501
        :type: TrafficManagementTypeResponse
        """
        if traffic_management_type is None:
            raise ValueError("Invalid value for `traffic_management_type`, must not be `None`")  # noqa: E501

        self._traffic_management_type = traffic_management_type

    @property
    def traffic_management_type_string(self):
        """Gets the traffic_management_type_string of this WorkProperties.  # noqa: E501


        :return: The traffic_management_type_string of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._traffic_management_type_string

    @traffic_management_type_string.setter
    def traffic_management_type_string(self, traffic_management_type_string):
        """Sets the traffic_management_type_string of this WorkProperties.


        :param traffic_management_type_string: The traffic_management_type_string of this WorkProperties.  # noqa: E501
        :type: str
        """
        if traffic_management_type_string is None:
            raise ValueError("Invalid value for `traffic_management_type_string`, must not be `None`")  # noqa: E501

        self._traffic_management_type_string = traffic_management_type_string

    @property
    def current_traffic_management_type(self):
        """Gets the current_traffic_management_type of this WorkProperties.  # noqa: E501


        :return: The current_traffic_management_type of this WorkProperties.  # noqa: E501
        :rtype: TrafficManagementTypeResponse
        """
        return self._current_traffic_management_type

    @current_traffic_management_type.setter
    def current_traffic_management_type(self, current_traffic_management_type):
        """Sets the current_traffic_management_type of this WorkProperties.


        :param current_traffic_management_type: The current_traffic_management_type of this WorkProperties.  # noqa: E501
        :type: TrafficManagementTypeResponse
        """

        self._current_traffic_management_type = current_traffic_management_type

    @property
    def current_traffic_management_type_string(self):
        """Gets the current_traffic_management_type_string of this WorkProperties.  # noqa: E501


        :return: The current_traffic_management_type_string of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._current_traffic_management_type_string

    @current_traffic_management_type_string.setter
    def current_traffic_management_type_string(self, current_traffic_management_type_string):
        """Sets the current_traffic_management_type_string of this WorkProperties.


        :param current_traffic_management_type_string: The current_traffic_management_type_string of this WorkProperties.  # noqa: E501
        :type: str
        """

        self._current_traffic_management_type_string = current_traffic_management_type_string

    @property
    def current_traffic_management_update_date(self):
        """Gets the current_traffic_management_update_date of this WorkProperties.  # noqa: E501


        :return: The current_traffic_management_update_date of this WorkProperties.  # noqa: E501
        :rtype: datetime
        """
        return self._current_traffic_management_update_date

    @current_traffic_management_update_date.setter
    def current_traffic_management_update_date(self, current_traffic_management_update_date):
        """Sets the current_traffic_management_update_date of this WorkProperties.


        :param current_traffic_management_update_date: The current_traffic_management_update_date of this WorkProperties.  # noqa: E501
        :type: datetime
        """

        self._current_traffic_management_update_date = current_traffic_management_update_date

    @property
    def street(self):
        """Gets the street of this WorkProperties.  # noqa: E501


        :return: The street of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._street

    @street.setter
    def street(self, street):
        """Sets the street of this WorkProperties.


        :param street: The street of this WorkProperties.  # noqa: E501
        :type: str
        """
        if street is None:
            raise ValueError("Invalid value for `street`, must not be `None`")  # noqa: E501

        self._street = street

    @property
    def usrn(self):
        """Gets the usrn of this WorkProperties.  # noqa: E501


        :return: The usrn of this WorkProperties.  # noqa: E501
        :rtype: float
        """
        return self._usrn

    @usrn.setter
    def usrn(self, usrn):
        """Sets the usrn of this WorkProperties.


        :param usrn: The usrn of this WorkProperties.  # noqa: E501
        :type: float
        """
        if usrn is None:
            raise ValueError("Invalid value for `usrn`, must not be `None`")  # noqa: E501

        self._usrn = usrn

    @property
    def town(self):
        """Gets the town of this WorkProperties.  # noqa: E501


        :return: The town of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._town

    @town.setter
    def town(self, town):
        """Sets the town of this WorkProperties.


        :param town: The town of this WorkProperties.  # noqa: E501
        :type: str
        """
        if town is None:
            raise ValueError("Invalid value for `town`, must not be `None`")  # noqa: E501

        self._town = town

    @property
    def area(self):
        """Gets the area of this WorkProperties.  # noqa: E501


        :return: The area of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._area

    @area.setter
    def area(self, area):
        """Sets the area of this WorkProperties.


        :param area: The area of this WorkProperties.  # noqa: E501
        :type: str
        """
        if area is None:
            raise ValueError("Invalid value for `area`, must not be `None`")  # noqa: E501

        self._area = area

    @property
    def highway_authority(self):
        """Gets the highway_authority of this WorkProperties.  # noqa: E501


        :return: The highway_authority of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._highway_authority

    @highway_authority.setter
    def highway_authority(self, highway_authority):
        """Sets the highway_authority of this WorkProperties.


        :param highway_authority: The highway_authority of this WorkProperties.  # noqa: E501
        :type: str
        """
        if highway_authority is None:
            raise ValueError("Invalid value for `highway_authority`, must not be `None`")  # noqa: E501

        self._highway_authority = highway_authority

    @property
    def work_centre_point(self):
        """Gets the work_centre_point of this WorkProperties.  # noqa: E501


        :return: The work_centre_point of this WorkProperties.  # noqa: E501
        :rtype: GeoJSONCentrePoint
        """
        return self._work_centre_point

    @work_centre_point.setter
    def work_centre_point(self, work_centre_point):
        """Sets the work_centre_point of this WorkProperties.


        :param work_centre_point: The work_centre_point of this WorkProperties.  # noqa: E501
        :type: GeoJSONCentrePoint
        """
        if work_centre_point is None:
            raise ValueError("Invalid value for `work_centre_point`, must not be `None`")  # noqa: E501

        self._work_centre_point = work_centre_point

    @property
    def permit_status(self):
        """Gets the permit_status of this WorkProperties.  # noqa: E501


        :return: The permit_status of this WorkProperties.  # noqa: E501
        :rtype: PermitStatusResponse
        """
        return self._permit_status

    @permit_status.setter
    def permit_status(self, permit_status):
        """Sets the permit_status of this WorkProperties.


        :param permit_status: The permit_status of this WorkProperties.  # noqa: E501
        :type: PermitStatusResponse
        """
        if permit_status is None:
            raise ValueError("Invalid value for `permit_status`, must not be `None`")  # noqa: E501

        self._permit_status = permit_status

    @property
    def permit_status_string(self):
        """Gets the permit_status_string of this WorkProperties.  # noqa: E501


        :return: The permit_status_string of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._permit_status_string

    @permit_status_string.setter
    def permit_status_string(self, permit_status_string):
        """Sets the permit_status_string of this WorkProperties.


        :param permit_status_string: The permit_status_string of this WorkProperties.  # noqa: E501
        :type: str
        """
        if permit_status_string is None:
            raise ValueError("Invalid value for `permit_status_string`, must not be `None`")  # noqa: E501

        self._permit_status_string = permit_status_string

    @property
    def industry_sector(self):
        """Gets the industry_sector of this WorkProperties.  # noqa: E501


        :return: The industry_sector of this WorkProperties.  # noqa: E501
        :rtype: AllOfWorkPropertiesIndustrySector
        """
        return self._industry_sector

    @industry_sector.setter
    def industry_sector(self, industry_sector):
        """Sets the industry_sector of this WorkProperties.


        :param industry_sector: The industry_sector of this WorkProperties.  # noqa: E501
        :type: AllOfWorkPropertiesIndustrySector
        """

        self._industry_sector = industry_sector

    @property
    def industry_sector_string(self):
        """Gets the industry_sector_string of this WorkProperties.  # noqa: E501


        :return: The industry_sector_string of this WorkProperties.  # noqa: E501
        :rtype: str
        """
        return self._industry_sector_string

    @industry_sector_string.setter
    def industry_sector_string(self, industry_sector_string):
        """Sets the industry_sector_string of this WorkProperties.


        :param industry_sector_string: The industry_sector_string of this WorkProperties.  # noqa: E501
        :type: str
        """

        self._industry_sector_string = industry_sector_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkProperties, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkProperties):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager Street Lookup API

    See API specification Resource Guide > Street Lookup API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AdditionalSpecialDesignationsResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'street_special_desig_code': 'AdditionalSpecialDesignationCodeResponse',
        'street_special_desig_code_string': 'str',
        'special_desig_location_text': 'str',
        'special_desig_description': 'str',
        'special_desig_start_time': 'float',
        'special_desig_end_time': 'float',
        'special_desig_periodicity_code': 'AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode',
        'special_desig_periodicity_code_string': 'str',
        'asd_coordinate_geometry': 'AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry',
        'whole_road': 'bool',
        'special_desig_start_date': 'datetime',
        'special_desig_end_date': 'datetime'
    }

    attribute_map = {
        'street_special_desig_code': 'street_special_desig_code',
        'street_special_desig_code_string': 'street_special_desig_code_string',
        'special_desig_location_text': 'special_desig_location_text',
        'special_desig_description': 'special_desig_description',
        'special_desig_start_time': 'special_desig_start_time',
        'special_desig_end_time': 'special_desig_end_time',
        'special_desig_periodicity_code': 'special_desig_periodicity_code',
        'special_desig_periodicity_code_string': 'special_desig_periodicity_code_string',
        'asd_coordinate_geometry': 'asd_coordinate_geometry',
        'whole_road': 'whole_road',
        'special_desig_start_date': 'special_desig_start_date',
        'special_desig_end_date': 'special_desig_end_date'
    }

    def __init__(self, street_special_desig_code=None, street_special_desig_code_string=None, special_desig_location_text=None, special_desig_description=None, special_desig_start_time=None, special_desig_end_time=None, special_desig_periodicity_code=None, special_desig_periodicity_code_string=None, asd_coordinate_geometry=None, whole_road=None, special_desig_start_date=None, special_desig_end_date=None):  # noqa: E501
        """AdditionalSpecialDesignationsResponse - a model defined in Swagger"""  # noqa: E501
        self._street_special_desig_code = None
        self._street_special_desig_code_string = None
        self._special_desig_location_text = None
        self._special_desig_description = None
        self._special_desig_start_time = None
        self._special_desig_end_time = None
        self._special_desig_periodicity_code = None
        self._special_desig_periodicity_code_string = None
        self._asd_coordinate_geometry = None
        self._whole_road = None
        self._special_desig_start_date = None
        self._special_desig_end_date = None
        self.discriminator = None
        self.street_special_desig_code = street_special_desig_code
        if street_special_desig_code_string is not None:
            self.street_special_desig_code_string = street_special_desig_code_string
        if special_desig_location_text is not None:
            self.special_desig_location_text = special_desig_location_text
        if special_desig_description is not None:
            self.special_desig_description = special_desig_description
        if special_desig_start_time is not None:
            self.special_desig_start_time = special_desig_start_time
        if special_desig_end_time is not None:
            self.special_desig_end_time = special_desig_end_time
        if special_desig_periodicity_code is not None:
            self.special_desig_periodicity_code = special_desig_periodicity_code
        if special_desig_periodicity_code_string is not None:
            self.special_desig_periodicity_code_string = special_desig_periodicity_code_string
        if asd_coordinate_geometry is not None:
            self.asd_coordinate_geometry = asd_coordinate_geometry
        if whole_road is not None:
            self.whole_road = whole_road
        if special_desig_start_date is not None:
            self.special_desig_start_date = special_desig_start_date
        if special_desig_end_date is not None:
            self.special_desig_end_date = special_desig_end_date

    @property
    def street_special_desig_code(self):
        """Gets the street_special_desig_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The street_special_desig_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: AdditionalSpecialDesignationCodeResponse
        """
        return self._street_special_desig_code

    @street_special_desig_code.setter
    def street_special_desig_code(self, street_special_desig_code):
        """Sets the street_special_desig_code of this AdditionalSpecialDesignationsResponse.


        :param street_special_desig_code: The street_special_desig_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: AdditionalSpecialDesignationCodeResponse
        """
        if street_special_desig_code is None:
            raise ValueError("Invalid value for `street_special_desig_code`, must not be `None`")  # noqa: E501

        self._street_special_desig_code = street_special_desig_code

    @property
    def street_special_desig_code_string(self):
        """Gets the street_special_desig_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The street_special_desig_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: str
        """
        return self._street_special_desig_code_string

    @street_special_desig_code_string.setter
    def street_special_desig_code_string(self, street_special_desig_code_string):
        """Sets the street_special_desig_code_string of this AdditionalSpecialDesignationsResponse.


        :param street_special_desig_code_string: The street_special_desig_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: str
        """

        self._street_special_desig_code_string = street_special_desig_code_string

    @property
    def special_desig_location_text(self):
        """Gets the special_desig_location_text of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_location_text of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: str
        """
        return self._special_desig_location_text

    @special_desig_location_text.setter
    def special_desig_location_text(self, special_desig_location_text):
        """Sets the special_desig_location_text of this AdditionalSpecialDesignationsResponse.


        :param special_desig_location_text: The special_desig_location_text of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: str
        """

        self._special_desig_location_text = special_desig_location_text

    @property
    def special_desig_description(self):
        """Gets the special_desig_description of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_description of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: str
        """
        return self._special_desig_description

    @special_desig_description.setter
    def special_desig_description(self, special_desig_description):
        """Sets the special_desig_description of this AdditionalSpecialDesignationsResponse.


        :param special_desig_description: The special_desig_description of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: str
        """

        self._special_desig_description = special_desig_description

    @property
    def special_desig_start_time(self):
        """Gets the special_desig_start_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_start_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: float
        """
        return self._special_desig_start_time

    @special_desig_start_time.setter
    def special_desig_start_time(self, special_desig_start_time):
        """Sets the special_desig_start_time of this AdditionalSpecialDesignationsResponse.


        :param special_desig_start_time: The special_desig_start_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: float
        """

        self._special_desig_start_time = special_desig_start_time

    @property
    def special_desig_end_time(self):
        """Gets the special_desig_end_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_end_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: float
        """
        return self._special_desig_end_time

    @special_desig_end_time.setter
    def special_desig_end_time(self, special_desig_end_time):
        """Sets the special_desig_end_time of this AdditionalSpecialDesignationsResponse.


        :param special_desig_end_time: The special_desig_end_time of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: float
        """

        self._special_desig_end_time = special_desig_end_time

    @property
    def special_desig_periodicity_code(self):
        """Gets the special_desig_periodicity_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_periodicity_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode
        """
        return self._special_desig_periodicity_code

    @special_desig_periodicity_code.setter
    def special_desig_periodicity_code(self, special_desig_periodicity_code):
        """Sets the special_desig_periodicity_code of this AdditionalSpecialDesignationsResponse.


        :param special_desig_periodicity_code: The special_desig_periodicity_code of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: AllOfAdditionalSpecialDesignationsResponseSpecialDesigPeriodicityCode
        """

        self._special_desig_periodicity_code = special_desig_periodicity_code

    @property
    def special_desig_periodicity_code_string(self):
        """Gets the special_desig_periodicity_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_periodicity_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: str
        """
        return self._special_desig_periodicity_code_string

    @special_desig_periodicity_code_string.setter
    def special_desig_periodicity_code_string(self, special_desig_periodicity_code_string):
        """Sets the special_desig_periodicity_code_string of this AdditionalSpecialDesignationsResponse.


        :param special_desig_periodicity_code_string: The special_desig_periodicity_code_string of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: str
        """

        self._special_desig_periodicity_code_string = special_desig_periodicity_code_string

    @property
    def asd_coordinate_geometry(self):
        """Gets the asd_coordinate_geometry of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The asd_coordinate_geometry of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry
        """
        return self._asd_coordinate_geometry

    @asd_coordinate_geometry.setter
    def asd_coordinate_geometry(self, asd_coordinate_geometry):
        """Sets the asd_coordinate_geometry of this AdditionalSpecialDesignationsResponse.


        :param asd_coordinate_geometry: The asd_coordinate_geometry of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: AllOfAdditionalSpecialDesignationsResponseAsdCoordinateGeometry
        """

        self._asd_coordinate_geometry = asd_coordinate_geometry

    @property
    def whole_road(self):
        """Gets the whole_road of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The whole_road of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: bool
        """
        return self._whole_road

    @whole_road.setter
    def whole_road(self, whole_road):
        """Sets the whole_road of this AdditionalSpecialDesignationsResponse.


        :param whole_road: The whole_road of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: bool
        """

        self._whole_road = whole_road

    @property
    def special_desig_start_date(self):
        """Gets the special_desig_start_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_start_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._special_desig_start_date

    @special_desig_start_date.setter
    def special_desig_start_date(self, special_desig_start_date):
        """Sets the special_desig_start_date of this AdditionalSpecialDesignationsResponse.


        :param special_desig_start_date: The special_desig_start_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: datetime
        """

        self._special_desig_start_date = special_desig_start_date

    @property
    def special_desig_end_date(self):
        """Gets the special_desig_end_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501


        :return: The special_desig_end_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._special_desig_end_date

    @special_desig_end_date.setter
    def special_desig_end_date(self, special_desig_end_date):
        """Sets the special_desig_end_date of this AdditionalSpecialDesignationsResponse.


        :param special_desig_end_date: The special_desig_end_date of this AdditionalSpecialDesignationsResponse.  # noqa: E501
        :type: datetime
        """

        self._special_desig_end_date = special_desig_end_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AdditionalSpecialDesignationsResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AdditionalSpecialDesignationsResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AuthenticationResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id_token': 'str',
        'organisation_reference': 'str',
        'access_token': 'str',
        'refresh_token': 'str',
        'session_token': 'str'
    }

    attribute_map = {
        'id_token': 'idToken',
        'organisation_reference': 'organisationReference',
        'access_token': 'accessToken',
        'refresh_token': 'refreshToken',
        'session_token': 'sessionToken'
    }

    def __init__(self, id_token=None, organisation_reference=None, access_token=None, refresh_token=None, session_token=None):  # noqa: E501
        """AuthenticationResponse - a model defined in Swagger"""  # noqa: E501
        self._id_token = None
        self._organisation_reference = None
        self._access_token = None
        self._refresh_token = None
        self._session_token = None
        self.discriminator = None
        if id_token is not None:
            self.id_token = id_token
        if organisation_reference is not None:
            self.organisation_reference = organisation_reference
        if access_token is not None:
            self.access_token = access_token
        if refresh_token is not None:
            self.refresh_token = refresh_token
        if session_token is not None:
            self.session_token = session_token

    @property
    def id_token(self):
        """Gets the id_token of this AuthenticationResponse.  # noqa: E501


        :return: The id_token of this AuthenticationResponse.  # noqa: E501
        :rtype: str
        """
        return self._id_token

    @id_token.setter
    def id_token(self, id_token):
        """Sets the id_token of this AuthenticationResponse.


        :param id_token: The id_token of this AuthenticationResponse.  # noqa: E501
        :type: str
        """

        self._id_token = id_token

    @property
    def organisation_reference(self):
        """Gets the organisation_reference of this AuthenticationResponse.  # noqa: E501


        :return: The organisation_reference of this AuthenticationResponse.  # noqa: E501
        :rtype: str
        """
        return self._organisation_reference

    @organisation_reference.setter
    def organisation_reference(self, organisation_reference):
        """Sets the organisation_reference of this AuthenticationResponse.


        :param organisation_reference: The organisation_reference of this AuthenticationResponse.  # noqa: E501
        :type: str
        """

        self._organisation_reference = organisation_reference

    @property
    def access_token(self):
        """Gets the access_token of this AuthenticationResponse.  # noqa: E501


        :return: The access_token of this AuthenticationResponse.  # noqa: E501
        :rtype: str
        """
        return self._access_token

    @access_token.setter
    def access_token(self, access_token):
        """Sets the access_token of this AuthenticationResponse.


        :param access_token: The access_token of this AuthenticationResponse.  # noqa: E501
        :type: str
        """

        self._access_token = access_token

    @property
    def refresh_token(self):
        """Gets the refresh_token of this AuthenticationResponse.  # noqa: E501


        :return: The refresh_token of this AuthenticationResponse.  # noqa: E501
        :rtype: str
        """
        return self._refresh_token

    @refresh_token.setter
    def refresh_token(self, refresh_token):
        """Sets the refresh_token of this AuthenticationResponse.


        :param refresh_token: The refresh_token of this AuthenticationResponse.  # noqa: E501
        :type: str
        """

        self._refresh_token = refresh_token

    @property
    def session_token(self):
        """Gets the session_token of this AuthenticationResponse.  # noqa: E501


        :return: The session_token of this AuthenticationResponse.  # noqa: E501
        :rtype: str
        """
        return self._session_token

    @session_token.setter
    def session_token(self, session_token):
        """Sets the session_token of this AuthenticationResponse.


        :param session_token: The session_token of this AuthenticationResponse.  # noqa: E501
        :type: str
        """

        self._session_token = session_token

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AuthenticationResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuthenticationResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Street Manager API

    See API specification Resource Guide > Work API for more information on endpoints NOTE: Swagger Editor/UI does not display all description text for enumerations and child elements, check swagger.json for full description text  # noqa: E501

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class WorkHistorySummaryResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'action_date': 'datetime',
        'topic': 'str',
        'details': 'str',
        'username': 'str',
        'event': 'AuditEvent',
        'event_string': 'str',
        'object_reference': 'str',
        'update_id': 'float',
        'internal_user_identifier': 'str',
        'internal_user_name': 'str'
    }

    attribute_map = {
        'action_date': 'action_date',
        'topic': 'topic',
        'details': 'details',
        'username': 'username',
        'event': 'event',
        'event_string': 'event_string',
        'object_reference': 'object_reference',
        'update_id': 'update_id',
        'internal_user_identifier': 'internal_user_identifier',
        'internal_user_name': 'internal_user_name'
    }

    def __init__(self, action_date=None, topic=None, details=None, username=None, event=None, event_string=None, object_reference=None, update_id=None, internal_user_identifier=None, internal_user_name=None):  # noqa: E501
        """WorkHistorySummaryResponse - a model defined in Swagger"""  # noqa: E501
        self._action_date = None
        self._topic = None
        self._details = None
        self._username = None
        self._event = None
        self._event_string = None
        self._object_reference = None
        self._update_id = None
        self._internal_user_identifier = None
        self._internal_user_name = None
        self.discriminator = None
        self.action_date = action_date
        self.topic = topic
        self.details = details
        self.username = username
        self.event = event
        self.event_string = event_string
        if object_reference is not None:
            self.object_reference = object_reference
        self.update_id = update_id
        if internal_user_identifier is not None:
            self.internal_user_identifier = internal_user_identifier
        if internal_user_name is not None:
            self.internal_user_name = internal_user_name

    @property
    def action_date(self):
        """Gets the action_date of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The action_date of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._action_date

    @action_date.setter
    def action_date(self, action_date):
        """Sets the action_date of this WorkHistorySummaryResponse.


        :param action_date: The action_date of this WorkHistorySummaryResponse.  # noqa: E501
        :type: datetime
        """
        if action_date is None:
            raise ValueError("Invalid value for `action_date`, must not be `None`")  # noqa: E501

        self._action_date = action_date

    @property
    def topic(self):
        """Gets the topic of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The topic of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._topic

    @topic.setter
    def topic(self, topic):
        """Sets the topic of this WorkHistorySummaryResponse.


        :param topic: The topic of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """
        if topic is None:
            raise ValueError("Invalid value for `topic`, must not be `None`")  # noqa: E501

        self._topic = topic

    @property
    def details(self):
        """Gets the details of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The details of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._details

    @details.setter
    def details(self, details):
        """Sets the details of this WorkHistorySummaryResponse.


        :param details: The details of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """
        if details is None:
            raise ValueError("Invalid value for `details`, must not be `None`")  # noqa: E501

        self._details = details

    @property
    def username(self):
        """Gets the username of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The username of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this WorkHistorySummaryResponse.


        :param username: The username of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """
        if username is None:
            raise ValueError("Invalid value for `username`, must not be `None`")  # noqa: E501

        self._username = username

    @property
    def event(self):
        """Gets the event of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The event of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: AuditEvent
        """
        return self._event

    @event.setter
    def event(self, event):
        """Sets the event of this WorkHistorySummaryResponse.


        :param event: The event of this WorkHistorySummaryResponse.  # noqa: E501
        :type: AuditEvent
        """
        if event is None:
            raise ValueError("Invalid value for `event`, must not be `None`")  # noqa: E501

        self._event = event

    @property
    def event_string(self):
        """Gets the event_string of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The event_string of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._event_string

    @event_string.setter
    def event_string(self, event_string):
        """Sets the event_string of this WorkHistorySummaryResponse.


        :param event_string: The event_string of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """
        if event_string is None:
            raise ValueError("Invalid value for `event_string`, must not be `None`")  # noqa: E501

        self._event_string = event_string

    @property
    def object_reference(self):
        """Gets the object_reference of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The object_reference of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._object_reference

    @object_reference.setter
    def object_reference(self, object_reference):
        """Sets the object_reference of this WorkHistorySummaryResponse.


        :param object_reference: The object_reference of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """

        self._object_reference = object_reference

    @property
    def update_id(self):
        """Gets the update_id of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The update_id of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: float
        """
        return self._update_id

    @update_id.setter
    def update_id(self, update_id):
        """Sets the update_id of this WorkHistorySummaryResponse.


        :param update_id: The update_id of this WorkHistorySummaryResponse.  # noqa: E501
        :type: float
        """
        if update_id is None:
            raise ValueError("Invalid value for `update_id`, must not be `None`")  # noqa: E501

        self._update_id = update_id

    @property
    def internal_user_identifier(self):
        """Gets the internal_user_identifier of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The internal_user_identifier of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_identifier

    @internal_user_identifier.setter
    def internal_user_identifier(self, internal_user_identifier):
        """Sets the internal_user_identifier of this WorkHistorySummaryResponse.


        :param internal_user_identifier: The internal_user_identifier of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """

        self._internal_user_identifier = internal_user_identifier

    @property
    def internal_user_name(self):
        """Gets the internal_user_name of this WorkHistorySummaryResponse.  # noqa: E501


        :return: The internal_user_name of this WorkHistorySummaryResponse.  # noqa: E501
        :rtype: str
        """
        return self._internal_user_name

    @internal_user_name.setter
    def internal_user_name(self, internal_user_name):
        """Sets the internal_user_name of this WorkHistorySummaryResponse.


        :param internal_user_name: The internal_user_name of this WorkHistorySummaryResponse.  # noqa: E501
        :type: str
        """

        self._internal_user_name = internal_user_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(WorkHistorySummaryResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkHistorySummaryResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
